@@ -22,8 +22,7 @@ OC.L10N.register(
     "Recent" : "Onlangs",
     "Shared with you" : "Met u gedeel",
     "Files" : " Lêers",
-    "Import" : "Voer In",
-    "Export" : "Voer uit",
+    "Settings" : "Instellings",
     "Bookmarklet" : "Boekmerkie",
     "Title" : "Titel",
     "Link" : "Skakel",
