@@ -9,6 +9,7 @@ OC.L10N.register(
     "Select all" : "Dibab pep tra",
     "New" : "Nevez",
     "New folder" : "Heuliad nevez",
+    "Search" : "Klask",
     "Sort by created date" : "Renkañ dre deizat krouidigezh",
     "Delete folder" : "Dilemel an teuliad",
     "Submit" : "Kinnig",
@@ -17,17 +18,16 @@ OC.L10N.register(
     "Shared with you" : "Rannet ganeoc'h",
     "Files" : "Restroù",
     "Broken links" : "Liammoù toret",
-    "Import" : "Emporzhiañ ",
+    "Settings" : "Arventennoù",
     "Title" : "Titl",
     "Link" : "Liamm",
     "Tags" : "Klavioù",
-    "Open file" : "Digeriñ ur restr",
+    "Download file" : "Pelkargañ restr",
     "Owner" : "Perc'henner",
     "Sharing" : "Rannan",
     "Share link" : "Rannan liamm",
     "Allow editing" : "Cheñchamentoù aotreet",
     "Allow resharing" : "Aotrea an adrannañ",
-    "Projects" : "Raktres",
     "Link copied" : "Liamm eilet",
     "Privacy" : "Prevezder",
     "Folder" : "Teuliad",
