@@ -13,8 +13,7 @@ OC.L10N.register(
     "Cancel" : "Otkaži",
     "Shared with you" : "Shared with you",
     "Files" : "Datoteke",
-    "Import" : "Uvoz",
-    "Export" : "Izvezi",
+    "Settings" : "Podešavanje",
     "Title" : "Naslov",
     "Link" : "Veza",
     "Notes" : "Notes",
