@@ -3,24 +3,24 @@ OC.L10N.register(
     {
     "Details" : "Manylion",
     "Rename" : "Ailenwi",
+    "Copy link" : "Copïo dolen",
     "Move" : "Symud",
     "Delete" : "Dileu",
     "Go back" : "Nôl",
     "New" : "Newydd",
     "New folder" : "Ffolder newydd",
+    "Search" : "Chwilio",
     "Cancel" : "Diddymu",
     "Recent" : "Diweddar",
     "Shared with you" : "Shared with you",
     "Files" : "Ffeiliau",
-    "Import" : "Mewnforio",
-    "Export" : "Allforio",
+    "Settings" : "Gosodiadau",
     "Title" : "Teitl",
     "Link" : "Dolen",
     "Tags" : "Tagiau",
     "Notes" : "Nodiadau",
     "Owner" : "Owner",
     "Share link" : "Rhannu dolen",
-    "Copy link" : "Copïo dolen",
     "Allow editing" : "Caniatáu golygu",
     "Link copied" : "Dolen wedi'i gopïo",
     "Folder" : "Plygell",
