@@ -107,17 +107,17 @@ OC.L10N.register(
     "Search tags" : "Ετικέτες αναζήτησης",
     "Untagged" : "Χωρίς ετικέτα",
     "{used} bookmarks of {available} available" : "Διαθέσιμοι  {available} σελιδοδείκτες από {used}",
+    "Settings" : "Ρυθμίσεις",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Οι σελιδοδείκτες σε αρχεία όπως φωτογραφίες ή PDF θα αποθηκευτούν αυτόματα στα αρχεία Nextcloud, ώστε να μπορείτε να τα βρείτε ακόμα και όταν ο σύνδεσμος είναι εκτός σύνδεσης.",
     "No bookmarks here" : "Δεν υπάρχουν σελιδοδείκτες εδώ",
-    "Import" : "Εισαγωγή",
-    "Export" : "Εξαγωγή",
-    "Archive path" : "Διαδρομή φακέλου αρχειοθέτησης",
     "Client apps" : "Εφαρμογές πελάτη",
     "Also check out the collection of client apps that integrate with this app: " : "Ελέγξτε επίσης τη συλλογή των εφαρμογών που ενσωματώνονται με αυτήν την εφαρμογή: ",
+    "Install web app" : "Εγκατάσταση εφαρμογής ιστού",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Μπορείτε να εγκαταστήσετε αυτήν την εφαρμογή στην αρχική οθόνη της συσκευής σας για γρήγορη πρόσβαση στους σελιδοδείκτες σας στο τηλέφωνό σας. Μπορείτε εύκολα να αφαιρέσετε ξανά την εφαρμογή από την αρχική οθόνη, αν δεν σας αρέσει.",
     "Install on home screen" : "Εγκατάσταση στην αρχική οθόνη",
     "Bookmarklet" : "Εφαρμογίδιο Σελιδοδεικτών",
     "Add to {instanceName}" : "Προσθήκη στο {instanceName}",
+    "Archive path" : "Διαδρομή φακέλου αρχειοθέτησης",
     "Please select \"Add to home screen\" in your browser menu" : "Παρακαλούμε επιλέξτε «Προσθήκη στην αρχική οθόνη» από το μενού του περιηγητή",
     "Title" : "Τίτλος",
     "Link" : "Σύνδεσμος",
@@ -185,7 +185,6 @@ OC.L10N.register(
     "Failed to delete folder" : "Απέτυχε η διαγραφή φακέλου",
     "Failed to create folder" : "Απέτυχε η δημιουργία φακέλου",
     "Failed to fetch bookmarks." : "Αποτυχία λήψης σελιδοδεικτών.",
-    "Failed to change setting" : "Αποτυχία αλλαγής επιλογών",
     "Failed to load setting {key}" : "Αποτυχία φόρτωσης ρυθμίσεων {key}",
     "Failed to update share {shareId}" : "Αποτυχία ενημέρωσης κοινόχρηστου {shareId}",
     "Failed to delete share {shareId}" : "Αποτυχία διαγραφής κοινόχρηστου {shareId}",
