@@ -10,6 +10,7 @@ OC.L10N.register(
     "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
+    "Search" : "Buscar",
     "Rename folder" : "Renombrar carpeta",
     "Delete folder" : "Borrar carpeta",
     "Choose folder" : "Elegir carpeta",
@@ -18,14 +19,13 @@ OC.L10N.register(
     "Recent" : "Reciente",
     "Shared with you" : "Compartido con usted",
     "Files" : "Archivos",
-    "Import" : "Importar",
-    "Export" : "Exportar",
+    "Settings" : "Ajustes",
     "Bookmarklet" : "Marcador a código",
     "Title" : "Título",
     "Link" : "Link",
     "Tags" : "Etiquetas",
     "Notes" : "Notas",
-    "Open file" : "Abrir archivo",
+    "Download file" : "Descargar archivo",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
     "Share link" : "Compartir enlace",
