@@ -41,13 +41,14 @@ OC.L10N.register(
     "Cancel selection" : "ביטול בחירה",
     "Selected {folders} folders and {bookmarks} bookmarks" : "נבחרו {folders} תיקיות ו־{bookmarks} סימניות",
     "Do you really want to delete these items?" : "למחוק את הפריטים האלה?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["סימנייה אחת נבחרה","%n סימניות נבחרו","%n סימניות נבחרו","%n סימניות נבחרו"],
+    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["סימנייה אחת נבחרה","%n סימניות נבחרו","%n סימניות נבחרו"],
     "_Selected %n folder_::_Selected %n folders_" : ["נבחרה תיקייה %n","נבחרו %n תיקיות","נבחרו %n תיקיות","נבחרו %n תיקיות"],
     "Go back" : "חזרה",
     "Select one or more tags" : "יש לבחור תגית אחת או יותר",
     "New" : "חדש",
     "New bookmark" : "סימנייה חדשה",
     "New folder" : "תיקייה חדשה",
+    "Search" : "חיפוש",
     "Enter a link" : "נא למלא קישור",
     "Enter a title" : "נא למלא כותרת",
     "No bookmarks found" : "לא נמצאו סימניות",
@@ -76,15 +77,15 @@ OC.L10N.register(
     "Broken links" : "קישורים פגומים",
     "Untagged" : "ללא תגית",
     "{used} bookmarks of {available} available" : "{used} סימניות מתוך {available} זמינות",
+    "Settings" : "הגדרות",
     "No bookmarks here" : "אין כאן סימניות",
-    "Import" : "ייבוא",
-    "Export" : "ייצוא",
-    "Archive path" : "נתיב הארכיון",
     "Client apps" : "יישומוני לקוח",
     "Also check out the collection of client apps that integrate with this app: " : "כדאי להציץ באוסף יישומוני הלקוח שמשתלבים עם היישומון הזה:",
+    "Install web app" : "התקנת יישומון דפדפן",
     "Install on home screen" : "התקנה על מסך הבית",
     "Bookmarklet" : "יישומון סימנייה",
     "Add to {instanceName}" : "הוספה אל {instanceName}",
+    "Archive path" : "נתיב הארכיון",
     "Please select \"Add to home screen\" in your browser menu" : "נא לבחור באפשרות „הוספה למסך הבית” בתפריט הדפדפן שלך",
     "Title" : "תפקיד",
     "Link" : "קישור",
@@ -92,7 +93,7 @@ OC.L10N.register(
     "Tags" : "תגיות",
     "Select tags and create new ones" : "בחירת תגיות ויצירת חדשות",
     "Notes" : "הערות",
-    "Open file" : "פתיחת קובץ",
+    "Download file" : "הורדת קובץ",
     "Created {time} ago" : "נוצר לפני {time}",
     "Owner" : "בעלות",
     "Sharing" : "שיתוף",
@@ -103,7 +104,6 @@ OC.L10N.register(
     "Allow editing" : "לאפשר עריכה",
     "Allow resharing" : "לאפשר שיתוף מחדש",
     "Remove share" : "הסרת שיתוף",
-    "Projects" : "מיזמים",
     "Link copied" : "הקישור הועתק",
     "Privacy" : "פרטיות",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "תכנית הסימניות תנסה לגשת אל האתרים שהוספת כדי להוסיף עליהן מידע אוטומטית.",
@@ -136,10 +136,9 @@ OC.L10N.register(
     "Failed to delete folder" : "מחיקת התיקייה נכשלה",
     "Failed to create folder" : "יצירת התיקייה נכשלה",
     "Failed to fetch bookmarks." : "קבלת הסימניות נכשלה.",
-    "Failed to change setting" : "שינוי ההגדרות נכשל",
     "Failed to load setting {key}" : "טעינת ההגדרה {key} נכשלה",
     "Failed to update share {shareId}" : "עדכון השיתוף {shareId} נכשל",
     "Failed to delete share {shareId}" : "מחיקת השיתוף {shareId} נכשלה",
     "Bookmarks feed" : "ערוץ סימניות"
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
