@@ -115,21 +115,20 @@ OC.L10N.register(
     "Search tags" : "Oznake pretraživanja",
     "Untagged" : "Uklonjene oznake",
     "{used} bookmarks of {available} available" : "{used} knjižnih oznaka od {available} dostupnih",
+    "Settings" : "Postavke",
     "No bookmarked files" : "Nema datoteka označenih kao knjižne oznake",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Knjižne oznake za datoteke, kao što su fotografije ili PDF datoteke, automatski će se spremiti među datoteke u vašem Nextcloudu tako da ih i dalje možete pronaći čak i izvan mreže.",
     "No bookmarks here" : "Ovdje nema knjižnih oznaka",
-    "Import" : "Uvezi",
-    "Export" : "Izvoz",
-    "Archive path" : "Put arhive",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Unesite put do mape u aplikaciji Files u kojoj trebaju biti pohranjene datoteke označene kao knjižne oznake.",
     "Client apps" : "Korisnička aplikacija",
     "Also check out the collection of client apps that integrate with this app: " : "Također pregledajte zbirku klijentskih aplikacija koje se mogu integrirati s ovom aplikacijom:",
-    "Install web app on device" : "Instaliraj web-aplikaciju",
+    "Install web app" : "Instaliraj web aplikaciju",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Ovu aplikaciju možete instalirati na početni zaslon uređaja kako biste mogli brzo pristupiti knjižnim oznakama na telefonu. Ako vam se aplikacija ne sviđa, lako je možete ukloniti s početnog zaslona.",
     "Install on home screen" : "Instaliraj na početni zaslon",
     "Bookmarklet" : "Bookmarklet",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Odvucite na knjižne oznake u svom pregledniku i kliknite kako biste brzo spremili mrežno mjesto u knjižne oznake.",
     "Add to {instanceName}" : "Dodaj u {instanceName}",
+    "Archive path" : "Put arhive",
     "Please select \"Add to home screen\" in your browser menu" : "Odaberite „Dodaj na početni zaslon“ u izborniku preglednika",
     "Title" : "Naslov",
     "Link" : "Poveznica",
@@ -199,7 +198,6 @@ OC.L10N.register(
     "Failed to delete folder" : "Brisanje mape nije uspjelo",
     "Failed to create folder" : "Stvaranje mape nije uspjelo",
     "Failed to fetch bookmarks." : "Dohvaćanje knjižnih oznaka nije uspjelo.",
-    "Failed to change setting" : "Promjena postavke nije uspjela",
     "Failed to load setting {key}" : "Učitavanje postavke {key} nije uspjelo",
     "Failed to update share {shareId}" : "Ažuriranje dijeljenja {shareId} nije uspjelo",
     "Failed to delete share {shareId}" : "Brisanje dijeljenja {shareId} nije uspjelo",
