@@ -27,7 +27,6 @@ OC.L10N.register(
     "Someone unshared folder \"%s\" with you" : "Valaki megszüntette a(z) „%s” mappa megosztását Önnel",
     "No file provided for import" : "Nincs fájl megadva az importáláshoz",
     "Unsupported file type for import" : "Nem támogatott fájltípus az importáláshoz",
-    "Bookmarks Backups" : "Könyvjelzők biztonsági mentése",
     "Bookmarks shared by %s" : "%s által megosztott könyvjelzők",
     "Frequent bookmarks" : "Gyakori könyvjelzők",
     "Recent bookmarks" : "Legújabb könyvjelzők",
@@ -38,6 +37,7 @@ OC.L10N.register(
     "Bookmark updated" : "Könyvjelző frissítve",
     "Create bookmark" : "Könyvjelző létrehozása",
     "Takes a link and adds it to your collection of bookmarks." : "Fog egy hivatkozást, és hozzáadja a könyvjelzők gyűjteményéhez.",
+    "Bookmarks Backups" : "Könyvjelzők biztonsági mentése",
     "A Bookmark manager for Nextcloud" : "Könyvjelzőkezelő a Nextcloudhoz",
     "Enter new title" : "Adja meg a címet",
     "Select bookmark" : "Válasszon könyvjelzőt",
@@ -125,6 +125,7 @@ OC.L10N.register(
     "Search tags" : "Címkék keresése",
     "Untagged" : "Nem címkézett",
     "{used} bookmarks of {available} available" : "{used} könyvjelző / {available} elérhető",
+    "Settings" : "Beállítások",
     "No bookmarked files" : "Nincsenek könyvjelzőzött fájlok",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "A fájlok, például a fényképek vagy a PDF-ek könyvjelzőit automatikusan menti az Ön Nextcloud fájljaiba, így akkor is megtalálhatja őket, ha a kapcsolat offline állapotban van.",
     "No broken links" : "Nincsenek törött hivatkozások",
@@ -132,21 +133,17 @@ OC.L10N.register(
     "No duplicated bookmarks" : "Nincsenek ismételt könyvjelzők",
     "No bookmarks here" : "Itt nincsenek könyvjelzők",
     "Add bookmarks manually or import bookmarks from a HTML file." : "Adjon hozzá könyvjelzőket kézzel, vagy importálja egy HTML-fájlból.",
-    "Import" : "Importálás",
-    "Export" : "Exportálás",
-    "Archive path" : "Archívum elérési útvonala",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Adja meg egy mappa elérési útját a Fájlokban, ahol a könyvjelzőket tárolni szeretné",
-    "Backups" : "Biztonsági mentések",
-    "Enable bookmarks backups" : "Könyvjelzők biztonsági mentésének engedélyezése",
     "Enter the path of a folder in your Files where backups will be stored." : "Adjon meg egy mappaútvonalat a Fájlokból, ahol a biztonsági mentések lesznek tárolva.",
     "Client apps" : "Kliensalkalmazások",
     "Also check out the collection of client apps that integrate with this app: " : "Nézze meg az alkalmazással integrált ügyfélalkalmazások gyűjteményét is: ",
-    "Install web app on device" : "Webalkalmazás telepítése az eszközre",
+    "Install web app" : "Web alkalmazás telepítése",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Telepítheti az alkalmazást az eszköze kezdőképernyőjére, hogy gyorsan elérje a könyvjelzőit a telefonján. Ha nem tetszik, akkor könnyedén el is távolítja az alkalmazást a kezdőképernyőjéről.",
     "Install on home screen" : "Telepítés a kezdőképernyőre",
     "Bookmarklet" : "Bookmarklet",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Húzza ezt a böngésző könyvjelzőihez, és kattintson rá a weboldal gyors könyvjelzőzéséhez.",
     "Add to {instanceName}" : "Hozzáadás ehhez: {instanceName}",
+    "Archive path" : "Archívum elérési útvonala",
     "Backup path" : "Biztonsági mentés útvonala",
     "Please select \"Add to home screen\" in your browser menu" : "Válassza a böngésző menüjében a „Hozzáadás a kezdőképernyőhöz” lehetőséget",
     "Title" : "Cím",
@@ -222,7 +219,6 @@ OC.L10N.register(
     "Failed to delete folder" : "A mappa törlése sikertelen",
     "Failed to create folder" : "A mappa létrehozása sikertelen",
     "Failed to fetch bookmarks." : "A könyvjelzők lekérése sikertelen.",
-    "Failed to change setting" : "A beállítások módosítása sikertelen",
     "Failed to load setting {key}" : "A(z) {key} beállítás betöltése sikertelen",
     "Failed to update share {shareId}" : "A megosztás frissítése sikertelen: {shareId}",
     "Failed to delete share {shareId}" : "A(z) {shareId} megosztás törlése sikertelen",
