@@ -13,8 +13,7 @@ OC.L10N.register(
     "Cancel" : "ընդհատել",
     "Shared with you" : "Shared with you",
     "Files" : "Ֆայլեր",
-    "Import" : "Ներմուծում",
-    "Export" : "Արտահանում",
+    "Settings" : "Կարգավորումներ",
     "Title" : "Վերնագիր",
     "Link" : "Հղում",
     "Notes" : "Notes",
