@@ -26,6 +26,7 @@ OC.L10N.register(
     "New" : "Nýtt",
     "New bookmark" : "Nýtt bókamerki",
     "New folder" : "Ný mappa",
+    "Search" : "Search",
     "Sort by created date" : "Sort by created date",
     "RSS feed copied" : "RSS-fréttastreymi afritað",
     "Enter a link" : "Settu inn slóð",
@@ -47,9 +48,8 @@ OC.L10N.register(
     "Files" : "Skrár",
     "Untagged" : "Ómerkt",
     "{used} bookmarks of {available} available" : "{used} bókamerki af {available} tiltækum",
+    "Settings" : "Stillingar",
     "No bookmarks here" : "Engin bókamerki hér",
-    "Import" : "Flytja inn",
-    "Export" : "Flytja út",
     "Client apps" : "Biðlaraforrit",
     "Also check out the collection of client apps that integrate with this app: " : "Skoðaðu einnig úrval þeirra biðlaraforrita sem samþættast þessu forriti:",
     "Bookmarklet" : "Bókamerklingur",
@@ -59,7 +59,7 @@ OC.L10N.register(
     "Root folder" : "Rótarmappa",
     "Tags" : "Merki",
     "Notes" : "Minnispunktar",
-    "Open file" : "Opna skrá",
+    "Download file" : "Sækja skrá",
     "Owner" : "Eigandi",
     "Sharing" : "Deiling",
     "Select a user or group" : "Veldu notanda eða hóp",
@@ -70,7 +70,6 @@ OC.L10N.register(
     "Allow editing" : "Leyfa breytingar",
     "Allow resharing" : "Leyfa endurdeilingu",
     "Remove share" : "Fjarlægja sameign",
-    "Projects" : "Verkefni",
     "Link copied" : "Tengill afritaður",
     "Privacy" : "Gagnaleynd",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bókamerkjaforritið mun reyna að fá aðgang að þeim síðum sem þú bætir við til að sækja sjálfvirkt upplýsingar um þær.",
@@ -100,7 +99,6 @@ OC.L10N.register(
     "Failed to delete folder" : "Mistókst að eyða möppu",
     "Failed to create folder" : "Mistókst að búa til möppu",
     "Failed to fetch bookmarks." : "Ekki tókst að sækja bókamerki.",
-    "Failed to change setting" : "Mistókst að breyta stillingu",
     "Failed to load setting {key}" : "Mistókst að hlaða inn {key} stillingunni",
     "Failed to update share {shareId}" : "Mistókst að uppfæra sameignina {shareId}",
     "Failed to delete share {shareId}" : "Mistókst að eyða sameigninni {shareId}",
