@@ -27,7 +27,6 @@ OC.L10N.register(
     "Someone unshared folder \"%s\" with you" : "誰かがフォルダー「%s」のあなたとの共有を解除しました",
     "No file provided for import" : "インポート用に提供されたファイルがありません",
     "Unsupported file type for import" : "インポートでサポートされていないファイル形式です",
-    "Bookmarks Backups" : "ブックマークのバックアップ",
     "Bookmarks shared by %s" : "%sさんから共有されたブックマーク",
     "Recent bookmarks" : "最新のブックマーク",
     "Bookmark" : "ブックマーク",
@@ -37,6 +36,7 @@ OC.L10N.register(
     "Bookmark updated" : "ブックマーク更新時",
     "Create bookmark" : "ブックマークを作成",
     "Takes a link and adds it to your collection of bookmarks." : "リンクを取得し、ブックマークのコレクションに追加します。",
+    "Bookmarks Backups" : "ブックマークのバックアップ",
     "A Bookmark manager for Nextcloud" : "Nextcloud のブックマークマネージャー",
     "Enter new title" : "新しいタイトルを入力",
     "Select bookmark" : "ブックマークを選択",
@@ -67,6 +67,7 @@ OC.L10N.register(
     "New folder" : "新しいフォルダー",
     "Change to grid view" : "グリッド表示へ変更する",
     "Change to list view" : "リスト表示へ変更する",
+    "Search" : "検索",
     "Sort by created date" : "作成日時順",
     "Sort by last modified" : "最終変更日時順",
     "Sort by title" : "タイトル順",
@@ -107,20 +108,18 @@ OC.L10N.register(
     "Search tags" : "タグを検索",
     "Untagged" : "タグなし",
     "{used} bookmarks of {available} available" : "利用可能ブックマーク数 {available} のうち{used} が使用済み ",
+    "Settings" : "設定",
     "No bookmarked files" : "ブックマーク済みファイルがありません",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "写真やPDFといったファイルへのブックマークは、自動的にNextcloudファイルとして保存されるため、リンクがオフラインになっても見つけることができます。",
     "No broken links" : "壊れたリンクなし",
     "No bookmarks here" : "ブックマークがありません",
-    "Import" : "インポート",
-    "Export" : "エクスポート",
-    "Archive path" : "アーカイブパス",
-    "Backups" : "バックアップ",
-    "Enable bookmarks backups" : "ブックマークのバックアップを有効化",
     "Client apps" : "クライアントアプリ",
     "Also check out the collection of client apps that integrate with this app: " : "このアプリと連携するクライアントアプリもご確認ください：",
+    "Install web app" : "Webアプリをインストール",
     "Install on home screen" : "ホーム画面へインストール",
     "Bookmarklet" : "ブックマークレット",
     "Add to {instanceName}" : "{instanceName}に追加",
+    "Archive path" : "アーカイブパス",
     "Please select \"Add to home screen\" in your browser menu" : "お使いのブラウザーで「ホーム画面に追加」を選択してください",
     "Title" : "タイトル",
     "Link" : "リンク",
@@ -130,7 +129,7 @@ OC.L10N.register(
     "Notes" : "ノート",
     "Notes for this bookmark …" : "このブックマークのメモ…",
     "Archived file" : "アーカイブ済みファイル",
-    "Open file" : "ファイルを開く",
+    "Download file" : "ダウンロードファイル",
     "Open file location" : "ファイルの場所を開く",
     "Created {time} ago" : "{time} 前に作成した",
     "Owner" : "所有者",
@@ -143,7 +142,6 @@ OC.L10N.register(
     "Allow editing" : "編集を許可",
     "Allow resharing" : "再共有を許可",
     "Remove share" : "共有を削除",
-    "Projects" : "プロジェクト",
     "Link copied" : "リンクをコピーしました",
     "Privacy" : "プライバシー",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "ブックマークは、追加したウェブページにアクセスして、それらに関する情報を自動的に追加しようとします。",
@@ -171,6 +169,7 @@ OC.L10N.register(
     "Root Folder" : "ルートフォルダー",
     "Save" : "保存",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "ネットワークアクセスはデフォルトで無効になっています。プレビューとfaviconの取得を許可するには、ブックマーク アプリの管理者設定を参照してください。",
+    "What" : "何を",
     "Failed to count unavailable bookmarks" : "利用不可ブックマークの数えに失敗しました",
     "Failed to count archived bookmarks" : "アーカイブ済みのブックマークの数えに失敗しました",
     "Failed to load bookmark" : "ブックマークの読込に失敗しました",
@@ -186,7 +185,6 @@ OC.L10N.register(
     "Failed to delete folder" : "フォルダーの削除に失敗しました",
     "Failed to create folder" : "ブックマークの作成に失敗しました",
     "Failed to fetch bookmarks." : "ブックマークの取得に失敗しました",
-    "Failed to change setting" : "設定の変更に失敗しました",
     "Failed to load setting {key}" : "設定の読込に失敗しました {key}",
     "Failed to update share {shareId}" : "共有の更新に失敗しました {shareId}",
     "Failed to delete share {shareId}" : "共有の削除に失敗しました {shareId}",
