@@ -23,8 +23,7 @@ OC.L10N.register(
     "Recent" : "ახალი",
     "Shared with you" : "გაზიარებული თქვენთან",
     "Files" : "ფაილები",
-    "Import" : "იმპორტი",
-    "Export" : "ექსპორტი",
+    "Settings" : "პარამეტრები",
     "Bookmarklet" : "Bookmarklet-ი",
     "Title" : "სათაური",
     "Link" : "ბმული",
