@@ -14,8 +14,7 @@ OC.L10N.register(
     "Cancel" : "បោះបង់",
     "Shared with you" : "Shared with you",
     "Files" : "ឯកសារ",
-    "Import" : "នាំយកចូល",
-    "Export" : "នាំចេញ",
+    "Settings" : "ការកំណត់",
     "Title" : "ចំណងជើង",
     "Link" : "Link",
     "Tags" : "ស្លាក",
