@@ -27,7 +27,6 @@ OC.L10N.register(
     "Someone unshared folder \"%s\" with you" : "누군가 \"%s\"에 대한 공유를 해제함",
     "No file provided for import" : "가져올 파일을 지정하지 않았음",
     "Unsupported file type for import" : "지원하지 않는 가져오기 파일 형식",
-    "Bookmarks Backups" : "북마크 백업",
     "Bookmarks shared by %s" : "%s님이 공유한 북마크 ",
     "Frequent bookmarks" : "자주 방문한 북마크",
     "Recent bookmarks" : "최근 북마크",
@@ -38,6 +37,7 @@ OC.L10N.register(
     "Bookmark updated" : "북마크가 갱신됨",
     "Create bookmark" : "북마크 생성",
     "Takes a link and adds it to your collection of bookmarks." : "링크를 북마크 목록에 추가하십시오.",
+    "Bookmarks Backups" : "북마크 백업",
     "A Bookmark manager for Nextcloud" : "Nextcloud 북마크 관리자",
     "Select bookmark" : "북마크 선택",
     "Details" : "자세한 정보",
@@ -71,8 +71,7 @@ OC.L10N.register(
     "Shared with you" : "나와 공유됨",
     "Files" : "파일",
     "Untagged" : "태그 지우기",
-    "Import" : "가져오기",
-    "Export" : "내보내기",
+    "Settings" : "설정",
     "Bookmarklet" : "북마크릿",
     "Add to {instanceName}" : "{instanceName}에 더하기",
     "Title" : "직위",
@@ -85,12 +84,14 @@ OC.L10N.register(
     "Sharing" : "공유",
     "Share link" : "링크 공유",
     "Delete link" : "링크 삭제",
-    "Allow editing" : "Allow editing",
+    "Editing allowed" : "수정 허용됨",
+    "Allow editing" : "수정 허용",
     "Allow resharing" : "재공유 허용",
     "Remove share" : "공유 삭제",
     "Link copied" : "링크 복사됨",
     "Privacy" : "프라이버시",
     "Performance" : "성능",
+    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "계정이 대량으로 존재할 경우 계정 당 최대 북마크 수를 제한하는 것이 좋습니다.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "계정 당 최대 북마크 수 (0을 입력할 시 무제한이며 이는 기본값입니다.)",
     "Previews" : "미리 보기",
     "Screeenly API URL" : "Screeenly API URL",
@@ -103,6 +104,8 @@ OC.L10N.register(
     "Folder" : "폴더",
     "Root Folder" : "최상위 폴더",
     "Save" : "저장",
+    "What" : "무엇을",
+    "Failed to load tags" : "태그 불러오기 실패",
     "Bookmarks feed" : "북마크 피드"
 },
 "nplurals=1; plural=0;");
