@@ -10,24 +10,24 @@ OC.L10N.register(
     "Go back" : "Zeréckgoen",
     "New" : "Nei",
     "New folder" : "Neien Dossier",
+    "Search" : "Search",
     "Rename folder" : "Dossier ëmbenennen",
     "Delete folder" : "Dossier läschen",
     "Cancel" : "Ofbriechen",
     "Recent" : "Rezent",
     "Shared with you" : "Mat dir gedeelt",
     "Files" : "Fichieren",
-    "Import" : "Importéieren",
-    "Export" : "Exportéieren",
+    "Settings" : "Astellungen",
     "Title" : "Titel",
     "Link" : "Link",
     "Tags" : "Tags",
     "Notes" : "Notizen",
-    "Open file" : "Fichier opmaachen",
     "Owner" : "Owner",
     "Sharing" : "Gedeelt",
     "Share link" : "Link deelen",
     "Allow editing" : "Beaarbechten erlaben",
     "Allow resharing" : "Resharing erlaben",
+    "Link copied" : "Link kopéiert",
     "Folder" : "Dossier",
     "Save" : "Späicheren"
 },
