@@ -36,6 +36,7 @@ OC.L10N.register(
     "New folder" : "Naujas aplankas",
     "Change to grid view" : "Keisti į tinklelio rodinį",
     "Change to list view" : "Keisti į sąrašo rodinį",
+    "Search" : "Ieškoti",
     "RSS feed copied" : "RSS kanalas nukopijuotas",
     "Enter a link" : "Įveskite nuorodą",
     "Add a bookmark" : "Pridėti adresyno įrašą",
@@ -56,9 +57,8 @@ OC.L10N.register(
     "Files" : "Failai",
     "New tag" : "Nauja žymė",
     "Untagged" : "Be žymių",
+    "Settings" : "Nustatymai",
     "No bookmarks here" : "Čia adresyno įrašų nėra",
-    "Import" : "Importuoti",
-    "Export" : "Eksportuoti",
     "Client apps" : "Kliento programėlės",
     "Add to {instanceName}" : "Pridėti į {instanceName}",
     "Title" : "Pareigos",
@@ -66,7 +66,7 @@ OC.L10N.register(
     "Root folder" : "Šakninis aplankas",
     "Tags" : "Žymės",
     "Notes" : "Pastabos",
-    "Open file" : "Atverti failą",
+    "Download file" : "Atsisiųsti failą",
     "Owner" : "Savininkas",
     "Sharing" : "Bendrinimas",
     "Select a user or group" : "Pasirinkti naudotoją ar grupę",
@@ -77,7 +77,6 @@ OC.L10N.register(
     "Allow editing" : "Leisti redaguoti",
     "Allow resharing" : "Leisti bendrinti iš naujo",
     "Remove share" : "Šalinti viešinį",
-    "Projects" : "Projektai",
     "Link copied" : "Nuoroda nukopijuota",
     "Privacy" : "Privatumas",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Adresynas bandys apsilankyti jūsų pridedamose internetinėse svetainėse, kad automatiškai pridėtų informaciją apie jas.",
@@ -107,7 +106,6 @@ OC.L10N.register(
     "Failed to delete folder" : "Nepavyko ištrinti aplanko",
     "Failed to create folder" : "Nepavyko sukurti aplanko",
     "Failed to fetch bookmarks." : "Nepavyko gauti adresyno įrašų.",
-    "Failed to change setting" : "Nepavyko pakeisti nustatymo",
     "Failed to load setting {key}" : "Nepavyko įkelti nustatymo {key}",
     "Failed to update share {shareId}" : "Nepavyko atnaujinti viešinio {shareId}",
     "Failed to delete share {shareId}" : "Nepavyko ištrinti viešinio {shareId}",
