@@ -24,8 +24,7 @@ OC.L10N.register(
     "Recent" : "Nesenās",
     "Shared with you" : "Koplietots ar jums",
     "Files" : "Datnes",
-    "Import" : "Importēt",
-    "Export" : "Eksportēt",
+    "Settings" : "Iestatījumi",
     "Bookmarklet" : "Grāmatzīme",
     "Title" : "Amats",
     "Link" : "Saite",
