@@ -21,8 +21,7 @@ OC.L10N.register(
     "Recent" : "Неодамнешни",
     "Shared with you" : "Споделено со вас",
     "Files" : "Датотеки",
-    "Import" : "Увези",
-    "Export" : "Извези",
+    "Settings" : "Параметри",
     "Title" : "Наслов",
     "Link" : "Линк",
     "Tags" : "Ознаки",
