@@ -21,6 +21,7 @@ OC.L10N.register(
     "New" : "Шинэ",
     "New folder" : "Шинэ хавтас",
     "Search" : "Хайх",
+    "_%n folder_::_%n folders_" : ["%n хавтас","%n хавтас"],
     "Delete folder" : "Хавтсыг устгах",
     "Choose folder" : "Хавтас сонгого уу",
     "Submit" : "мэдэгдэх",
@@ -28,8 +29,7 @@ OC.L10N.register(
     "Recent" : "Сүүлийн үеийн",
     "Shared with you" : "тантай хуваалцсан",
     "Files" : "файлууд",
-    "Import" : "Импорт",
-    "Export" : "Экспорт",
+    "Settings" : "Тохиргоо",
     "Title" : "Цол/Албан тушаал",
     "Link" : "Холбоос",
     "Tags" : "Tag-үүд",
