@@ -71,6 +71,7 @@ OC.L10N.register(
     "Change to list view" : "Omschakelen naar lijstweergave",
     "Copy RSS Feed of current view" : "Kopieer RSS feed van huidige weergave",
     "The RSS feed requires authentication with your Nextcloud credentials" : "De RSS-feed vereist authenticatie met je Nextcloud-inloggegevens",
+    "Search" : "Zoeken",
     "Sort by created date" : "Sorteer op aanmaakdatum",
     "Sort by last modified" : "Op wijzigingsdatum sorteren",
     "Sort by title" : "Sorteer op titel",
@@ -115,23 +116,21 @@ OC.L10N.register(
     "Search tags" : "Zoek in tags",
     "Untagged" : "Niet getagd",
     "{used} bookmarks of {available} available" : "{used} bladwijzers van {available} beschikbare",
+    "Settings" : "Instellingen",
     "No bookmarked files" : "Geen bladwijzers voor bestanden",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bladwijzers naar bestanden zoals foto's of PDF's worden automatisch opgeslagen in je Nextcloud bestanden, zodat je ze nog steeds kunt vinden, zelfs als de link offline gaat.",
     "No duplicated bookmarks" : "Geen duplicaat bladwijzers",
     "No bookmarks here" : "Geen bookmarks hier",
-    "Import" : "Importeren",
-    "Export" : "Exporteren",
-    "Archive path" : "Archief pad",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Voer het pad van een map in je Bestanden in waar bladwijzers opgeslagen moeten worden.",
-    "Backups" : "Backups",
     "Client apps" : "Client apps",
     "Also check out the collection of client apps that integrate with this app: " : "Bekijk ook de verzameling client-apps die met deze app kunnen worden geïntegreerd:",
-    "Install web app on device" : "Installeer web-app op een toestel",
+    "Install web app" : "Installeer web-app",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Je kunt deze app op het startscherm van je toestel installeren om daarmee snel toegang te krijgen tot de bladwijzers op je telefoon. Je kunt de app eenvoudig weer van je startscherm verwijderen, als je die niet leuk vindt.",
     "Install on home screen" : "Installeren op thuisscherm",
     "Bookmarklet" : "Bookmarklet",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Sleep dit naar je browser bladwijzers en open het om snel een bladwijzer van een website te maken.",
     "Add to {instanceName}" : "Toevoegen aan {instanceName}",
+    "Archive path" : "Archief pad",
     "Backup path" : "Back-up pad",
     "Please select \"Add to home screen\" in your browser menu" : "Selecteer 'Voeg toe aan thuisscherm' in je browser menu",
     "Title" : "Titel",
@@ -143,7 +142,7 @@ OC.L10N.register(
     "Notes" : "Notities",
     "Notes for this bookmark …" : "Notities voor deze bladwijzer...",
     "Archived file" : "Gearchiveerd bestand",
-    "Open file" : "Openen bestand",
+    "Download file" : "Downloaden bestand",
     "Open file location" : "Open bestandslocatie",
     "Created {time} ago" : "{time} geleden gecreëerd",
     "Created on {date}" : "Aangemaakt op {date}",
@@ -160,7 +159,6 @@ OC.L10N.register(
     "Allow editing" : "Bewerken toestaan",
     "Allow resharing" : "Verder delen toestaan",
     "Remove share" : "Verwijder share",
-    "Projects" : "Projecten",
     "Link copied" : "Link gekopieerd",
     "Privacy" : "Privacy",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bladwijzers zal proberen toegang te krijgen tot webpagina's die je toevoegt om automatisch informatie erover toevoegen.",
@@ -203,7 +201,6 @@ OC.L10N.register(
     "Failed to delete folder" : "Kon map niet verwijderen",
     "Failed to create folder" : "Kon map niet aanmaken",
     "Failed to fetch bookmarks." : "Kon bladwijzer niet ophalen",
-    "Failed to change setting" : "Kon instellingen niet wijzigen",
     "Failed to load setting {key}" : "Kon instelling niet laden {key}",
     "Failed to update share {shareId}" : "Share uploaden mislukt {shareId}",
     "Failed to delete share {shareId}" : "Kan de share niet verwijderen {shareId}",
