@@ -13,6 +13,7 @@ OC.L10N.register(
     "Share folder" : "Partilhar pasta",
     "New" : "Novo",
     "New folder" : "Nova pasta",
+    "Search" : "Pesquisa sobre",
     "Add a bookmark" : "Adicionar um marcador",
     "Rename folder" : "Renomear pasta",
     "Delete folder" : "Apagar pasta",
@@ -23,14 +24,13 @@ OC.L10N.register(
     "Recent" : "Recentes",
     "Shared with you" : "Partilhado consigo",
     "Files" : "Ficheiros",
-    "Import" : "Importar",
-    "Export" : "Exportar",
+    "Settings" : "Definições",
     "Title" : "Título",
     "Link" : "Link",
     "Root folder" : "Pasta raiz",
     "Tags" : "Marcações",
     "Notes" : "Notas",
-    "Open file" : "Abrir ficheiro",
+    "Download file" : "Transferir ficheiro",
     "Owner" : "Proprietário",
     "Sharing" : "Partilha",
     "Select a user or group" : "Selecionar utilizador ou grupo",
