@@ -19,8 +19,7 @@ OC.L10N.register(
     "Recent" : "Recente",
     "Shared with you" : "Partajat cu tine",
     "Files" : "Fișiere",
-    "Import" : "Importă",
-    "Export" : "Exportă",
+    "Settings" : "Setări",
     "Title" : "Titlu",
     "Link" : "Legătură",
     "Root folder" : "Folder principal",
