@@ -27,7 +27,6 @@ OC.L10N.register(
     "Someone unshared folder \"%s\" with you" : "Nekdo vam onemogoči souporabo mape »%s«",
     "No file provided for import" : "Ni navedenih datotek za uvoz",
     "Unsupported file type for import" : "Nepodprta vrsta datoteke za uvoz",
-    "Bookmarks Backups" : "Varnostne kopije zaznamkov",
     "Bookmarks shared by %s" : "Zaznamki v souporabi z %s",
     "Frequent bookmarks" : "Pogosti zaznamki",
     "Recent bookmarks" : "Nedavni zaznamki",
@@ -38,6 +37,7 @@ OC.L10N.register(
     "Bookmark updated" : "Zaznamek je posodobljen",
     "Create bookmark" : "Ustvari zaznamek",
     "Takes a link and adds it to your collection of bookmarks." : "Prevzame povezavo in jo doda v zbirko zaznamkov.",
+    "Bookmarks Backups" : "Varnostne kopije zaznamkov",
     "A Bookmark manager for Nextcloud" : "Upravljalnik zaznamkov za Nextcloud",
     "Enter new title" : "Vpis novega naslova",
     "Select bookmark" : "Izbor zaznamka",
@@ -125,6 +125,7 @@ OC.L10N.register(
     "Search tags" : "Poišči oznake",
     "Untagged" : "Neoznačeno",
     "{used} bookmarks of {available} available" : "Uporabljeno {used} od razpoložljivih {available}",
+    "Settings" : "Nastavitve",
     "No bookmarked files" : "Ni še dodanih zaznamkov datotek",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Zaznamki do datotek, kot so slike in dokumenti PDF, bodo samodejno shranjeni med datoteke Nextcloud, zato je dostop mogoč tudi pri delu brez povezave.",
     "No broken links" : "Ni okvarjenih povezav",
@@ -132,21 +133,17 @@ OC.L10N.register(
     "No duplicated bookmarks" : "Ni podvojenih zaznamkov",
     "No bookmarks here" : "Ni še dodanih zaznamkov.",
     "Add bookmarks manually or import bookmarks from a HTML file." : "Zaznamke dodajte ročno ali jih uvozite iz datoteke HTML.",
-    "Import" : "Uvozi",
-    "Export" : "Izvozi",
-    "Archive path" : "Arhiviraj pot",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Vpis poti do mape med Datotekami, kjer bi morali biti shranjeni zaznamki datotek",
-    "Backups" : "Varnostne kopije",
-    "Enable bookmarks backups" : "Omogoči varnostno kopiranje zaznamkov",
     "Enter the path of a folder in your Files where backups will be stored." : "Vpis poti do mape med Datotekami, kjer naj bodo shranjene varnostne kopije zaznamkov.",
     "Client apps" : "Odjemalski programi",
     "Also check out the collection of client apps that integrate with this app: " : "Preverite tudi zbirko programov, ki se povezujejo z zmožnostmi:",
-    "Install web app on device" : "Na napravo namesti spletni program",
+    "Install web app" : "Namesti spletni program",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Program je mogoče dodati na začetni zaslon za hiter dostop do zaznamkov na telefonu. Prav tako je program mogoče enostavno odstraniti z začetnega zaslona.",
     "Install on home screen" : "Namesti na začetni zaslon",
     "Bookmarklet" : "Program za zaznamke",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Potegnite to med zaznamke brskalnika in kliknite za hitro dodajanje zaznamka spletne strani.",
     "Add to {instanceName}" : "Dodaj {instanceName} ",
+    "Archive path" : "Arhiviraj pot",
     "Backup path" : "Varnostna kopija poti",
     "Please select \"Add to home screen\" in your browser menu" : "V meniju brskalnika izberite možnost »Dodaj na začetni zaslon«",
     "Title" : "Naslov",
@@ -205,7 +202,6 @@ OC.L10N.register(
     "Save" : "Shrani",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Omrežni dostop je onemogočen privzeto. Med skrbniškimi nastavitvami za program zaznamkov so zbrane možnosti pridobivanja predogleda in ikon.",
     "What" : "Dejanje",
-    "Link to a bookmark folder" : "Povezava do mape zaznamkov",
     "Failed to count unavailable bookmarks" : "Štetje nerazpoložljivih zaznamkov je spodletelo",
     "Failed to count archived bookmarks" : "Štetje arhiviranih zaznamkov je spodletelo",
     "Failed to count duplicated bookmarks" : "Preštevanje podvojenih zaznamkov je spodletelo",
@@ -222,7 +218,6 @@ OC.L10N.register(
     "Failed to delete folder" : "Brisanje mape je spodletelo",
     "Failed to create folder" : "Ustvarjanje mape je spodletelo",
     "Failed to fetch bookmarks." : "Pridobivanje zaznamkov je spodletelo",
-    "Failed to change setting" : "Spreminjanje nastavitev je spodletelo",
     "Failed to load setting {key}" : "Nalaganje ključa nastavitve {key} je spodletelo",
     "Failed to update share {shareId}" : "Posodabljanje {shareId} je spodletelo",
     "Failed to delete share {shareId}" : "Brisanje {shareId} je spodletelo",
