@@ -37,6 +37,7 @@ OC.L10N.register(
     "Bookmark updated" : "Bokmärke uppdaterat",
     "Create bookmark" : "Skapa bokmärke",
     "Takes a link and adds it to your collection of bookmarks." : "Tar en länk och lägger till den i dina bokmärken.",
+    "Bookmarks Backups" : "Bokmärken säkerhetskopior",
     "A Bookmark manager for Nextcloud" : "En bokmärkeshanterare för Nextcloud",
     "Enter new title" : "Ange ny titel",
     "Select bookmark" : "Välj bokmärke",
@@ -44,11 +45,20 @@ OC.L10N.register(
     "Rename" : "Byt namn",
     "Copy link" : "Kopiera länk",
     "Move" : "Flytta",
+    "Add to folders" : "Lägg till i mappar",
     "Delete" : "Ta bort",
     "Do you really want to delete this bookmark?" : "Är du säker att du vill ta bort detta bokmärket?",
     "Link copied to clipboard" : "Länken kopierad till urklipp",
     "Content pending" : "Innehåll förestår",
     "This content is being downloaded for offline use. Please check back later." : "Detta innehåll laddas ner för offlineanvändning. Vänligen försök igen senare.",
+    "Bookmarked {time} ago" : "Sparad för {time} sedan",
+    "Bookmarked on {date}" : "Sparad den {date}",
+    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer på webben som foton eller PDF-filer sparas automatiskt till dina Nextcloud-filer, så att du fortfarande kan hitta dem även när länken går offline.",
+    "Searching in the current folder only." : "Söker endast i nuvarande mappen.",
+    "Repeat search in all folders" : "Upprepa sökning i alla mappar",
+    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Bokmärkta länkar kontrolleras regelbundet och de som inte kan nås listas här.",
+    "You can share bookmark folders with others. All folders shared with you are listed here." : "Du kan dela bokmärkesmappar med andra. Alla mappar som delas med dig listas här.",
+    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Ett bokmärke kan finnas i flera mappar samtidigt. Om du uppdaterar en, uppdateras alla kopior. Alla dubbletter av bokmärken listas här.",
     "Open all selected" : "Öppna alla markerade",
     "Move selection" : "Flytta urval",
     "Edit tags of selection" : "Ändra taggar för urval",
@@ -75,13 +85,16 @@ OC.L10N.register(
     "Sort by title" : "Sortera efter titel",
     "Sort by click count" : "Sortera efter antal klicks",
     "Sort by manual order" : "Sortera efter manuell ordning",
+    "Sort by URL" : "Sortera efter URL",
     "RSS feed copied" : "Kopierade RSS flöde",
+    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Lägger till %n bokmärke i ny mapp","Lägger till %n bokmärken i ny mapp"],
     "Enter a link" : "Ange en länk",
     "Enter a title" : "Ange en titel",
     "No bookmarks found" : "Inga bokmärken hittades",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} mappar och {bookmarks} bokmärken",
     "_%n bookmark_::_%n bookmarks_" : ["%n bokmärke","%n bokmärken"],
     "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
+    "Welcome to Bookmarks" : "Välkommen till Bokmärken",
     "Add a bookmark" : "Lägg till ett bokmärke",
     "Import bookmarks" : "Importera bokmärken",
     "Sync with your browser" : "Synkronisera med din webbläsare",
@@ -99,6 +112,7 @@ OC.L10N.register(
     "Deleting selection" : "Tar bort urval",
     "Importing bookmarks" : "Importerar bokmärken",
     "Moving selection" : "Flyttar urval",
+    "Adding selection to folders" : "Lägger till urval i mappar",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flyttar %n mapp och några bokmärken","Flyttar %n mappar och några bokmärken"],
     "_Moving %n folder_::_Moving %n folders_" : ["Flyttar %n mapp","Flyttar %n mappar"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flyttar %n bokmärke","Flyttar %n bokmärken"],
@@ -106,27 +120,47 @@ OC.L10N.register(
     "Recent" : "Nya",
     "Shared with you" : "Delat med dig",
     "Files" : "Filer",
+    "Duplicates" : "Dubbletter",
     "Broken links" : "Brutna länkar",
     "New tag" : "Ny tagg",
     "Search tags" : "Sök taggar",
     "Untagged" : "Inte taggad",
     "{used} bookmarks of {available} available" : "{used} bokmärken av {available} tillgängliga",
+    "Settings" : "Inställningar",
     "No bookmarked files" : "Inga bokmärkta filer",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer som foton eller PDF-filer sparas automatiskt i ditt Nextcloud så att du fortfarande kan hitta dem även när länken går offline.",
+    "Nothing found" : "Inget hittades",
+    "Your search yielded no results in the current folder." : "Din sökning gav inga resultat i den nuvarande mappen.",
+    "No broken links" : "Inga trasiga länkar",
+    "No shared folders" : "Inga delade mappar",
+    "No duplicated bookmarks" : "Inga dubblerade bokmärken",
     "No bookmarks here" : "Inga bokmärken här",
-    "Import" : "Importera",
-    "Export" : "Exportera",
-    "Archive path" : "Sökväg till arkiv",
+    "Add bookmarks manually or import bookmarks from a HTML file." : "Lägg till bokmärken manuellt eller importera bokmärken från en HTML-fil.",
+    "Bookmarks settings" : "Bokmärkesinställningar",
+    "Import/Export" : "Import/Export",
+    "Export bookmarks" : "Exportera bokmärken",
+    "Auto-archiving" : "Auto-arkivering",
+    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Bokmärkesappen kan automatiskt arkivera webbinnehållet för länkar du har bokmärkt.",
+    "Enable archiving" : "Aktivera arkivering",
+    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Ange sökvägen till en mapp i dina filer där bokmärkta filer ska lagras.",
+    "Auto-Backup" : "Automatisk säkerhetskopiering",
+    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Bokmärkesappen kan automatiskt säkerhetskopiera dina bokmärken dagligen för att förhindra dataförlust när du synkroniserar bokmärken mellan enheter.",
+    "Enable backups" : "Aktivera säkerhetskopiering",
+    "Enter the path of a folder in your Files where backups will be stored." : "Ange sökvägen till en mapp i dina filer där säkerhetskopior kommer att lagras.",
     "Client apps" : "Klientappar",
     "Also check out the collection of client apps that integrate with this app: " : "Kolla också in samlingen av klientappar som integrerar med den här appen: ",
-    "Install web app on device" : "Installera webbapp på denna enhet",
+    "Install web app" : "Installera webbapp",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Du kan installera denna appen på hemskärmen av din enhet för att snabbt komma åt dina bokmärken från din mobil. Du kan enkelt ta bort appen från hemskärmen igen ifall du inte gillar det.",
     "Install on home screen" : "Installera på hemskärmen",
     "Bookmarklet" : "Bookmarklet",
+    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Dra till webbläsarens bokmärken och klicka på den för att snabbt bokmärka en webbplats.",
     "Add to {instanceName}" : "Lägg till {instanceName}",
+    "Archive path" : "Sökväg till arkiv",
+    "Backup path" : "Sökväg till säkerhetskopior",
     "Please select \"Add to home screen\" in your browser menu" : "Vänligen välj \"Lägg till hemskärm\" i din webbläsarmeny",
     "Title" : "Titel",
     "Link" : "Länk",
+    "Untitled folder" : "Namnlös mapp",
     "Root folder" : "Topp-mapp",
     "Tags" : "Taggar",
     "Select tags and create new ones" : "Välj taggar och skapa nya",
@@ -168,6 +202,8 @@ OC.L10N.register(
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachine API nyckel",
     "Pageres CLI" : "Pageres CLI",
+    "Simply install the Pageres CLI on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Installera Pageres CLI på din server så hittar Bokmärken det. Du kan fortfarande lägga till ytterligare ENV-variabler som ska matas till Pageres, t.ex. som anges i platshållaren:",
+    "Pageres ENV variables" : "Pageres ENV-variabler",
     "Failed to save settings" : "Kunde inte spara inställningarna",
     "Failed to load settings" : "Kunde inte läsa in inställningar",
     "This URL is already bookmarked! Overwrite?" : "Den här webbadressen är redan bokmärkt! Skriva över?",
@@ -177,14 +213,17 @@ OC.L10N.register(
     "Root Folder" : "Rot mapp",
     "Save" : "Spara",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Nätverkstillgång är inaktiv som standard. Gå till administratör-inställningarna för bokmärkesappen för att tillåta hämtning av förhandsvisningar och ikoner.",
+    "What's new in Bookmarks?" : "Vad är nytt i Bokmärken?",
     "What" : "Vad",
     "Failed to count unavailable bookmarks" : "Det gick inte att räkna otillgängliga bokmärken",
     "Failed to count archived bookmarks" : "Det gick inte att räkna arkiverade bokmärken",
+    "Failed to count duplicated bookmarks" : "Det gick inte att räkna dubblerade bokmärken",
     "Failed to load bookmark" : "Det gick inte att läsa in bokmärket",
     "Failed to find existing bookmark" : "Kunde inte hitta befintligt bokmärke",
     "Failed to create bookmark" : "Kunde inte skapa bokmärke",
     "Failed to save bookmark" : "Kunde inte spara bokmärke",
     "Failed to move bookmark" : "Kunde inte flytta bokmärke",
+    "Failed to copy bookmark" : "Kunde inte kopiera bokmärket",
     "Failed to delete bookmark" : "Kunde inte radera bokmärke",
     "Failed to rename tag" : "Kunde inte döpa om tagg",
     "Failed to load tags" : "Kunde inte läsa in taggar",
@@ -192,10 +231,12 @@ OC.L10N.register(
     "Failed to delete folder" : "Kunde inte radera mapp",
     "Failed to create folder" : "Kunde inte skapa mapp",
     "Failed to fetch bookmarks." : "Kunde inte hämta bokmärken.",
-    "Failed to change setting" : "Kunde inte ändra inställning",
+    "Failed to store setting" : "Kunde inte spara inställning",
     "Failed to load setting {key}" : "Det gick inte att läsa in inställningen {key}",
     "Failed to update share {shareId}" : "Det gick inte att uppdatera delningen {shareId}",
     "Failed to delete share {shareId}" : "Det gick inte att radera delningen {shareId}",
+    "Create bookmarks for mentioned links" : "Skapa bokmärken för nämnda länkar",
+    "No links found in this message" : "Inga länkar hittades i detta meddelande",
     "Bookmarks feed" : "Bokmärkesflöde"
 },
 "nplurals=2; plural=(n != 1);");
