@@ -6,12 +6,12 @@ OC.L10N.register(
     "Move" : "Move",
     "Delete" : "நீக்குக",
     "New" : "புதிய",
+    "Search" : "Search",
     "Delete folder" : "கோப்பை அழிக்க",
     "Cancel" : "இரத்து செய்க",
     "Shared with you" : "Shared with you",
     "Files" : "கோப்புகள்",
-    "Import" : "இறக்குமதி",
-    "Export" : "ஏற்றுமதி",
+    "Settings" : "அமைப்புகள்",
     "Title" : "தலைப்பு",
     "Link" : "Link",
     "Tags" : "சீட்டுகள்",
