@@ -19,8 +19,7 @@ OC.L10N.register(
     "Recent" : "ล่าสุด",
     "Shared with you" : "แชร์กับคุณ",
     "Files" : "ไฟล์",
-    "Import" : "นำเข้า",
-    "Export" : "ส่งออก",
+    "Settings" : "การตั้งค่า",
     "Title" : "ชื่อเรื่อง",
     "Link" : "ลิงก์",
     "Tags" : "แท็ก",
@@ -33,6 +32,8 @@ OC.L10N.register(
     "Allow resharing" : "อนุญาตให้แชร์ซ้ำ",
     "Link copied" : "คัดลอกลิงก์แล้ว",
     "Privacy" : "ความเป็นส่วนตัว",
+    "Failed to save settings" : "ไม่สามารถบันทึกการตั้งค่าได้",
+    "Failed to load settings" : "ไม่สามารถโหลดการตั้งค่าได้",
     "Folder" : "โฟลเดอร์",
     "Save" : "บันทึก"
 },
