@@ -6,13 +6,13 @@ OC.L10N.register(
     "Delete" : "ئۆچۈر",
     "New" : "يېڭى",
     "New folder" : "يېڭى قىسقۇچ",
+    "Search" : "Search",
     "Rename folder" : "قىسقۇچ ئاتىنى ئۆزگەرت",
     "Delete folder" : "قىسقۇچ ئۆچۈر",
     "Cancel" : "ۋاز كەچ",
     "Shared with you" : "Shared with you",
     "Files" : "ھۆججەتلەر",
-    "Import" : "ئەكىر",
-    "Export" : "چىقار",
+    "Settings" : "تەڭشەكلەر",
     "Title" : "ماۋزۇ",
     "Link" : "Link",
     "Tags" : "بەلگەلەر",
