@@ -9,7 +9,8 @@ OC.L10N.register(
     "Copy link" : "Копіювати посилання",
     "Move" : "Перемістити",
     "Delete" : "Вилучити",
-    "This content is being downloaded for offline use. Please check back later." : "Вміст завантажується для використання в режимі офлайн. Будь ласка, перевірте пізніше.",
+    "Link copied to clipboard" : "Посилання скопійовано в буфер обміну",
+    "This content is being downloaded for offline use. Please check back later." : "Вміст звантажується для використання в автономному режимі. Будь ласка, перевірте пізніше.",
     "Delete selection" : "Прибрати виділення",
     "Select all" : "Вибрати все",
     "Go back" : "Повернутися назад",
@@ -32,13 +33,13 @@ OC.L10N.register(
     "Recent" : "Нещодавні",
     "Shared with you" : "Вам надано доступ",
     "Files" : "Робота з файлами",
-    "Import" : "Імпорт",
-    "Export" : "Експорт",
+    "Settings" : "Налаштування",
     "Title" : "Назва",
     "Link" : "Посилання",
     "Root folder" : "Кореневий каталог",
     "Tags" : "Мітки",
     "Notes" : "Примітки",
+    "Download file" : "Звантажити файл",
     "Created {time} ago" : "Створено {time} тому",
     "Owner" : "Власник",
     "Sharing" : "Поділитися",
@@ -50,12 +51,14 @@ OC.L10N.register(
     "Allow resharing" : "Дозволити передавати у спільний доступ іншим",
     "Link copied" : "Посилання скопійовано",
     "Privacy" : "Конфіденційність",
+    "Performance" : "Продуктивність",
     "Failed to save settings" : "Неможливо зберегти налаштування",
     "Failed to load settings" : "Не вдалося завантажити налаштування",
     "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
     "Folder" : "Каталог",
     "Save" : "Зберегти",
     "What" : "Що?",
-    "Failed to load tags" : "Не вдалося завантажити мітки"
+    "Failed to load tags" : "Не вдалося завантажити мітки",
+    "Failed to fetch bookmarks." : "Не вдалося отримати закладки."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
