@@ -27,7 +27,6 @@ OC.L10N.register(
     "Someone unshared folder \"%s\" with you" : "有人取消了开放给您的%s文件夹共享",
     "No file provided for import" : "未提供导入文件",
     "Unsupported file type for import" : "不支持导入的文件类型",
-    "Bookmarks Backups" : "书签备份",
     "Bookmarks shared by %s" : "由 %s 共享的书签",
     "Frequent bookmarks" : "常用书签",
     "Recent bookmarks" : "近期书签",
@@ -38,6 +37,7 @@ OC.L10N.register(
     "Bookmark updated" : "书签已更新",
     "Create bookmark" : "创建书签",
     "Takes a link and adds it to your collection of bookmarks." : "获取一个链接并将其添加到您的书签中。",
+    "Bookmarks Backups" : "书签备份",
     "A Bookmark manager for Nextcloud" : "适用于 Nextcloud 的书签管理",
     "Enter new title" : "输入新标题",
     "Select bookmark" : "选择书签",
@@ -125,6 +125,7 @@ OC.L10N.register(
     "Search tags" : "搜索标签",
     "Untagged" : "未标记的",
     "{used} bookmarks of {available} available" : " {available}书签可用，已用{used}",
+    "Settings" : "设置",
     "No bookmarked files" : "无已添加书签的文件",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或PDF等文件的书签会被自动保存到你的Nextcloud文件中，因此即使链接离线，你仍然可以找到它们。",
     "No broken links" : "没有失效的链接",
@@ -132,21 +133,17 @@ OC.L10N.register(
     "No duplicated bookmarks" : "没有重复的书签",
     "No bookmarks here" : "无书签",
     "Add bookmarks manually or import bookmarks from a HTML file." : "手动添加书签或从HTML文件中导入书签。",
-    "Import" : "导入",
-    "Export" : "导出",
-    "Archive path" : "归档路径",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "输入一个文件夹路径，加书签的文件会被存储至该文件夹",
-    "Backups" : "备份",
-    "Enable bookmarks backups" : "启用书签备份",
     "Enter the path of a folder in your Files where backups will be stored." : "输入一个存储备份的文件夹的路径。",
     "Client apps" : "客户端应用",
     "Also check out the collection of client apps that integrate with this app: " : "还可以查看与此应用集成的客户端应用集合：",
-    "Install web app on device" : "在设备上安装 Web 应用",
+    "Install web app" : "安装Web应用",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "你可以在你的设备主屏幕上安装这个应用程序来快速访问你手机上的书签。如果你不喜欢它，你可以很容易地从主屏幕上删除它。",
     "Install on home screen" : "安装到主屏幕",
     "Bookmarklet" : "小书签",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "将此拖到浏览器书签中，并单击它可快速将网页添加为书签。",
     "Add to {instanceName}" : "添加到 {instanceName}",
+    "Archive path" : "归档路径",
     "Backup path" : "备份路径",
     "Please select \"Add to home screen\" in your browser menu" : "请点击浏览器菜单中的“添加到主屏幕”",
     "Title" : "标题",
@@ -221,7 +218,6 @@ OC.L10N.register(
     "Failed to delete folder" : "删除文件夹失败",
     "Failed to create folder" : "创建文件夹失败",
     "Failed to fetch bookmarks." : "获取书签失败",
-    "Failed to change setting" : "修改设置失败",
     "Failed to load setting {key}" : "加载设置{key}失败",
     "Failed to update share {shareId}" : "更新共享{shareId}失败",
     "Failed to delete share {shareId}" : "删除共享{shareId}失败",
