@@ -27,7 +27,6 @@ OC.L10N.register(
     "Someone unshared folder \"%s\" with you" : "某人已取消與你共用的資料夾 \"%s\"",
     "No file provided for import" : "無匯入檔案",
     "Unsupported file type for import" : "匯入不支援的檔案格式",
-    "Bookmarks Backups" : "書籤備份",
     "Bookmarks shared by %s" : "由 %s 共用的書籤",
     "Frequent bookmarks" : "常用書籤",
     "Recent bookmarks" : "最近使用的書籤",
@@ -38,6 +37,7 @@ OC.L10N.register(
     "Bookmark updated" : "書籤已更新",
     "Create bookmark" : "已建立書籤",
     "Takes a link and adds it to your collection of bookmarks." : "將連結添加到您的書籤收藏。",
+    "Bookmarks Backups" : "書籤備份",
     "A Bookmark manager for Nextcloud" : "Nextcloud上的書籤管理員",
     "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- 🔍 Full-text search\n- 📲 Synchronize with all your browsers and devices\n- 👪 Share bookmarks with other users and publicly\n- ☠ Find broken links\n- ⚛ Generate RSS feeds of your collections\n- 📔 Read archived versions of your links in case they are depublished\n- 💬 Create new bookmarks directly from within Nextcloud Talk\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 將書籤分類到資料夾中\n- 🏷 新增標籤與個人筆記\n- 🔍 全文搜尋\n- 📲 與您所有的瀏覽器及裝置同步\n- 👪 與其他用戶分享或是公開分享\n- ☠ 尋找壞掉的連結\n- ⚛ 產生您收藏的 RSS 摘要\n- 📔 若您的連結被取消發佈，您還是可以閱讀它們的封存版本\n- 💬 直接從 Nextcloud Talk 建立新書籤\n- 💼 用於經常造訪與最近新增連結的內建儀表板小工具\n\n系統需求：\n - PHP 擴充套件：\n   - intl: *\n   - mbstring: *\n - 若使用 MySQL，則至少需要 v8.0",
     "Enter new title" : "輸入新的標題",
@@ -55,6 +55,8 @@ OC.L10N.register(
     "Bookmarked {time} ago" : "{time} 前加入書籤",
     "Bookmarked on {date}" : "於 {date} 加入書籤",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "網絡上的檔案（如照片或 PDF）的書籤將自動保存到您的 Nextcloud 檔案中，因此即使連結離線，您也仍然可以找到它們。",
+    "Searching in the current folder only." : "僅在目前資料夾中搜尋。",
+    "Repeat search in all folders" : "在所有資料夾中重複搜尋",
     "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "已加入書籤的連結會定期檢查，無法存取的連結就會在此列出。",
     "You can share bookmark folders with others. All folders shared with you are listed here." : "您可以與其他人分享書籤資料夾。此處列出了與您分享的所有資料夾。",
     "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "一個書籤可以同時位於多個文件夾中。 更新它將更新所有副本。 為方便起見，此處列出了所有重複的書籤。",
@@ -126,30 +128,38 @@ OC.L10N.register(
     "Search tags" : "搜索標籤",
     "Untagged" : "未標記",
     "{used} bookmarks of {available} available" : "{available} 個可用書籤中的 {used} 個。",
+    "Settings" : "設定",
     "No bookmarked files" : "沒有已加書籤的檔案",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或PDF等檔案的書籤將自動保存到您的Nextcloud檔案中，因此即使連結脫機，您仍然可以找到它們。",
+    "Nothing found" : "沒有找到任何內容",
+    "Your search yielded no results in the current folder." : "您的搜尋在目前資料夾中沒有任何結果。",
     "No broken links" : "沒有失效的連結",
     "No shared folders" : "沒有已分享的資料夾",
     "No duplicated bookmarks" : "沒有書籤複本",
     "No bookmarks here" : "無書籤",
     "Add bookmarks manually or import bookmarks from a HTML file." : "手動添加書籤或從 HTML 檔案導入書籤。",
-    "Import" : "匯入",
-    "Export" : "導出",
-    "Archive path" : "封存路徑",
+    "Bookmarks settings" : "書籤設定",
+    "Import/Export" : "導入/導出",
+    "Export bookmarks" : "導出書籤",
+    "Auto-archiving" : "自動封存",
+    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "書籤應用程式可以自動封存您加入書籤的網路內容",
+    "Enable archiving" : "啟用封存",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "輸入應該存儲書籤檔案的資料夾的路徑",
-    "Backups" : "備份",
-    "Enable bookmarks backups" : "啟用書籤備份",
+    "Auto-Backup" : "自動備份",
+    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "書籤應用程式可以每天自動備份您的書籤，以防止跨裝置同步書籤時遺失資料。",
+    "Enable backups" : "啟用備份",
     "Enter the path of a folder in your Files where backups will be stored." : "輸入在您「檔案」中要儲存備份的資料夾路徑。",
     "Client apps" : "客戶端 apps",
     "Also check out the collection of client apps that integrate with this app: " : "還請檢查與此應用程序集成的客戶端應用程序的集合：",
-    "Install web app on device" : "在設備上安裝 web 應用程式",
-    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "您可以在設備主屏幕上安裝此應用程序以快速訪問手機上的書籤。如果您不喜歡它，您可以輕鬆地再次從主屏幕中刪除該應用程式。",
-    "Install on home screen" : "在主屏幕上安裝",
+    "Install web app" : "安裝 web 應用程式",
+    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "您可以在設備主螢幕上安裝此應用程序以快速訪問手機上的書籤。如果您不喜歡它，您可以輕鬆地再次從主螢幕中刪除該應用程式。",
+    "Install on home screen" : "在主螢幕上安裝",
     "Bookmarklet" : "書籤",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "將此拖拉到您瀏覽器書籤中且點擊它以快速為網頁添加書籤。",
     "Add to {instanceName}" : "加到 {instanceName}",
+    "Archive path" : "封存路徑",
     "Backup path" : "備份路徑",
-    "Please select \"Add to home screen\" in your browser menu" : "請在瀏覽器菜單中選擇“添加到主屏幕”",
+    "Please select \"Add to home screen\" in your browser menu" : "請在瀏覽器菜單中選擇“添加到主螢幕”",
     "Title" : "標題",
     "Link" : "連結",
     "Untitled folder" : "未命名資料夾",
@@ -181,10 +191,10 @@ OC.L10N.register(
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "書籤將嘗試存取您添加的網頁，以自動添加有關它們的信息。",
     "Enable accessing and collecting information from the web pages you add" : "從您增加的網頁啟用存取及收集資訊",
     "Performance" : "效能",
-    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "在具有大量用戶的安裝中，限制每個賬戶的書籤數量可能很有用。",
+    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "在具有大量用戶的安裝中，限制每個帳戶的書籤數量可能很有用。",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "每個帳號可以允許的書籤最大數量。（0是無限制; 預設是無限制）",
     "Previews" : "預覽",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "為了顯示您添加了書籤的網站的真實屏幕截圖，Bookmarks 可以使用第三方服務來生成預覽。",
+    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "為了顯示您添加了書籤的網站的真實螢幕截圖，Bookmarks 可以使用第三方服務來生成預覽。",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "您可以免費在 screeenly。com 註冊或是設定您自己的伺服器。",
     "Screeenly API URL" : "Screeenly API URL",
@@ -207,7 +217,6 @@ OC.L10N.register(
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "默認情況下，網絡存取處於停用狀態。轉到書籤應用程式的管理員設置，以啟用獲取預覽和網站圖標的功能。",
     "What's new in Bookmarks?" : "書籤有什麼新功能？",
     "What" : "甚麼",
-    "Link to a bookmark folder" : "連結至書籤資料夾",
     "Failed to count unavailable bookmarks" : "無法點算不可用的書籤",
     "Failed to count archived bookmarks" : "無法點算已封存的書籤",
     "Failed to count duplicated bookmarks" : "無法點算書籤複本",
@@ -224,7 +233,7 @@ OC.L10N.register(
     "Failed to delete folder" : "刪除資料夾失敗",
     "Failed to create folder" : "建立資料夾失敗",
     "Failed to fetch bookmarks." : "擷取書籤失敗",
-    "Failed to change setting" : "變更設定失敗",
+    "Failed to store setting" : "儲存設定失敗",
     "Failed to load setting {key}" : "載入設定失敗 {key}",
     "Failed to update share {shareId}" : "更新分享失敗 {shareId}",
     "Failed to delete share {shareId}" : "無法刪除分享 {shareId}",
