@@ -27,7 +27,6 @@ OC.L10N.register(
     "Someone unshared folder \"%s\" with you" : "某人已取消與你分享的資料夾「%s」",
     "No file provided for import" : "未提供要匯入的檔案",
     "Unsupported file type for import" : "匯入不支援的檔案格式",
-    "Bookmarks Backups" : "書籤備份",
     "Bookmarks shared by %s" : "由 %s 分享的書籤",
     "Frequent bookmarks" : "常用書籤",
     "Recent bookmarks" : "最近的書籤",
@@ -38,6 +37,7 @@ OC.L10N.register(
     "Bookmark updated" : "書籤已更新",
     "Create bookmark" : "建立書籤",
     "Takes a link and adds it to your collection of bookmarks." : "取得連結並新增到您的書籤集合中。",
+    "Bookmarks Backups" : "書籤備份",
     "A Bookmark manager for Nextcloud" : "Nextcloud 上的書籤管理程式",
     "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- 🔍 Full-text search\n- 📲 Synchronize with all your browsers and devices\n- 👪 Share bookmarks with other users and publicly\n- ☠ Find broken links\n- ⚛ Generate RSS feeds of your collections\n- 📔 Read archived versions of your links in case they are depublished\n- 💬 Create new bookmarks directly from within Nextcloud Talk\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 將書籤分類到資料夾中\n- 🏷 新增標籤與個人筆記\n- 🔍 全文搜尋\n- 📲 與您所有的瀏覽器及裝置同步\n- 👪 與其他使用者分享或是公開分享\n- ☠ 尋找壞掉的連結\n- ⚛ 產生您收藏的 RSS 摘要\n- 📔 若您的連結被取消發佈，您還是可以閱讀它們的封存版本\n- 💬 直接從 Nextcloud Talk 建立新書籤\n- 💼 用於經常造訪與最近新增連結的內建儀表板小工具\n\n系統需求：\n - PHP 擴充套件：\n   - intl: *\n   - mbstring: *\n - 若使用 MySQL，則至少需要 v8.0",
     "Enter new title" : "輸入新的標題",
@@ -55,6 +55,8 @@ OC.L10N.register(
     "Bookmarked {time} ago" : "{time} 前加入書籤",
     "Bookmarked on {date}" : "於 {date} 加入書籤",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "網路上的檔案（如照片或 PDF 等）的書籤將會自動儲存到您的 Nextcloud 檔案中，因此即便連結離線，您也仍然可以找到它們。",
+    "Searching in the current folder only." : "僅在目前資料夾中搜尋。",
+    "Repeat search in all folders" : "在所有資料夾中重複搜尋",
     "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "已加入書籤的連結會定期檢查，無法存取的連結就會在此列出。",
     "You can share bookmark folders with others. All folders shared with you are listed here." : "您可以與其他人分享書籤資料夾。此處列出了與您分享的所有資料夾。",
     "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "一個書籤可以同時位於多個資料夾中。更新它將會更新所有副本。為了方便起見，此處列出了所有重複的書籤。",
@@ -126,28 +128,36 @@ OC.L10N.register(
     "Search tags" : "搜尋標籤",
     "Untagged" : "無標籤",
     "{used} bookmarks of {available} available" : "{used} 書籤，可用 {available}",
+    "Settings" : "設定",
     "No bookmarked files" : "沒有已加入書籤的檔案",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或 PDF 等檔案的書籤將會自動儲存到您的 Nextcloud 檔案中，因此即便連結離線，您也仍然可以找到它們。",
+    "Nothing found" : "找不到東西",
+    "Your search yielded no results in the current folder." : "您的搜尋在目前資料夾中沒有任何結果。",
     "No broken links" : "沒有失效的連結",
     "No shared folders" : "沒有已分享的資料夾",
     "No duplicated bookmarks" : "沒有重複的書籤",
     "No bookmarks here" : "此處無書籤",
     "Add bookmarks manually or import bookmarks from a HTML file." : "手動新增書籤或從 HTML 檔案匯入。",
-    "Import" : "匯入",
-    "Export" : "匯出",
-    "Archive path" : "封存路徑",
+    "Bookmarks settings" : "書籤設定",
+    "Import/Export" : "匯入/匯出",
+    "Export bookmarks" : "匯出書籤",
+    "Auto-archiving" : "自動封存",
+    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "書籤應用程式可以自動封存您加入書籤的網路內容",
+    "Enable archiving" : "啟用封存",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "輸入要儲存書籤檔案的資料夾路徑。",
-    "Backups" : "備份",
-    "Enable bookmarks backups" : "啟用書籤備份",
+    "Auto-Backup" : "自動備份",
+    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "書籤應用程式可以每天自動備份您的書籤，以防止跨裝置同步書籤時遺失資料。",
+    "Enable backups" : "啟用備份",
     "Enter the path of a folder in your Files where backups will be stored." : "輸入在您「檔案」中要儲存備份的資料夾路徑。",
     "Client apps" : "客戶端應用程式",
     "Also check out the collection of client apps that integrate with this app: " : "還要檢查與此應用程式整合的客戶端應用程式集合：",
-    "Install web app on device" : "在裝置上安裝網路應用程式",
+    "Install web app" : "安裝網路應用程式",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "您可以在裝置主畫面上安裝此應用程式以在您的手機上快速存取您的書籤。如果您不喜歡它，您也可以輕鬆地再次從主畫面移除它。",
     "Install on home screen" : "安裝於主畫面",
     "Bookmarklet" : "書籤",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "將這個拖曳到您的瀏覽器書籤中，並點擊它以快速將網頁加入書籤。",
     "Add to {instanceName}" : "新增到 {instanceName}",
+    "Archive path" : "封存路徑",
     "Backup path" : "備份路徑",
     "Please select \"Add to home screen\" in your browser menu" : "請在您的瀏覽器選單中選取「新增至主畫面」",
     "Title" : "標題",
@@ -207,7 +217,6 @@ OC.L10N.register(
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "預設情況下停用網路存取。到管理設定中讓書籤應用程式可以擷取預覽與 favicon。",
     "What's new in Bookmarks?" : "書籤有什麼新功能？",
     "What" : "什麼",
-    "Link to a bookmark folder" : "連結至書籤資料夾",
     "Failed to count unavailable bookmarks" : "計算不可用的書籤失敗",
     "Failed to count archived bookmarks" : "計算已封存的書籤失敗",
     "Failed to count duplicated bookmarks" : "重複書籤計數失敗",
@@ -224,7 +233,7 @@ OC.L10N.register(
     "Failed to delete folder" : "刪除資料夾失敗",
     "Failed to create folder" : "建立資料夾失敗",
     "Failed to fetch bookmarks." : "擷取書籤失敗",
-    "Failed to change setting" : "變更設定失敗",
+    "Failed to store setting" : "儲存設定失敗",
     "Failed to load setting {key}" : "載入設定 {key} 失敗",
     "Failed to update share {shareId}" : "更新分享 {shareId} 失敗",
     "Failed to delete share {shareId}" : "刪除分享 {shareId} 失敗",
