@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
  * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
@@ -14,5 +14,5 @@ interface IBookmarkPreviewer {
 	 * @param Bookmark $bookmark
 	 * @return IImage|null
 	 */
-	public function getImage($bookmark): ?IImage;
+	public function getImage($bookmark, $cacheOnly = false): ?IImage;
 }
