@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
  * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
@@ -18,6 +18,7 @@ use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\Entity;
 use OCP\AppFramework\Db\MultipleObjectsReturnedException;
 use OCP\AppFramework\Db\QBMapper;
+use OCP\DB\Exception;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IConfig;
@@ -128,17 +129,17 @@ class TreeMapper extends QBMapper {
 		return call_user_func($entityClass . '::fromRow', $row);
 	}
 
-
 	/**
 	 * 	 * Runs a sql query and returns an array of entities
 	 * 	 *
 	 *
 	 * @param IQueryBuilder $query
 	 * @param string $type
-	 *
+	 * @psalm-param T $type
+	 * @psalm-template T as self::TYPE_*
+	 * @psalm-template E as (T is self::TYPE_FOLDER ? Folder : (T is self::TYPE_BOOKMARK ? Bookmark : SharedFolder))
 	 * @return Entity[] all fetched entities
-	 *
-	 * @psalm-return list<Entity>
+	 * @psalm-return list<E>
 	 */
 	protected function findEntitiesWithType(IQueryBuilder $query, string $type): array {
 		$cursor = $query->execute();
@@ -160,7 +161,10 @@ class TreeMapper extends QBMapper {
 	 *
 	 * @param IQueryBuilder $query
 	 * @param string $type
-	 * @return Entity the entity
+	 * @psalm-param T $type
+	 * @return E the entity
+	 * @psalm-template T as self::TYPE_*
+	 * @psalm-template E as (T is self::TYPE_FOLDER ? Folder : (T is self::TYPE_BOOKMARK ? Bookmark : SharedFolder))
 	 * @throws DoesNotExistException if the item does not exist
 	 * @throws MultipleObjectsReturnedException if more than one item exist
 	 */
@@ -174,7 +178,7 @@ class TreeMapper extends QBMapper {
 	 * @param IQueryBuilder|null $queryBuilder
 	 * @return IQueryBuilder
 	 */
-	protected function selectFromType(string $type, array $cols = [], IQueryBuilder $queryBuilder = null): IQueryBuilder {
+	protected function selectFromType(string $type, array $cols = [], ?IQueryBuilder $queryBuilder = null): IQueryBuilder {
 		$qb = $queryBuilder ?? $this->db->getQueryBuilder();
 		$qb->resetQueryPart('from');
 		$qb
@@ -230,21 +234,26 @@ class TreeMapper extends QBMapper {
 	/**
 	 * @param int $folderId
 	 * @param string $type
+	 * @psalm-param T $type
 	 *
 	 * @return Entity[]
+	 * @psalm-template T as self::TYPE_*
+	 * @psalm-template E as (T is self::TYPE_FOLDER ? Folder : (T is self::TYPE_BOOKMARK ? Bookmark : SharedFolder))
 	 *
-	 * @psalm-return array<array-key, Entity>
+	 * @psalm-return list<E>
 	 */
 	public function findChildren(string $type, int $folderId): array {
-		$qb = $this->getChildrenQuery[$type];
+		$qb = $this->selectFromType($type, [], $this->getChildrenQuery[$type]);
 		$qb->setParameter('parent_folder', $folderId);
 		return $this->findEntitiesWithType($qb, $type);
 	}
 
 	/**
 	 * @param string $type
+	 * @psalm-param self::TYPE_* $type
 	 * @param int $itemId
 	 * @return Entity
+	 * @psalm-return Folder
 	 * @throws DoesNotExistException
 	 * @throws MultipleObjectsReturnedException
 	 */
@@ -254,16 +263,16 @@ class TreeMapper extends QBMapper {
 			'id' => $itemId,
 			'type' => $type,
 		]);
-		return $this->findEntityWithType($qb, $type);
+		return $this->findEntityWithType($qb, self::TYPE_FOLDER);
 	}
 
 	/**
 	 * @param string $type
+	 * @psalm-param self::TYPE_* $type
 	 * @param int $itemId
 	 *
 	 * @return Entity[]
-	 *
-	 * @psalm-return array<array-key, Entity>
+	 * @psalm-return list<Folder>
 	 */
 	public function findParentsOf(string $type, int $itemId): array {
 		$qb = $this->parentQuery;
@@ -276,8 +285,12 @@ class TreeMapper extends QBMapper {
 
 	/**
 	 * @param string $type
+	 * @psalm-param T $type
 	 * @param int $folderId
-	 * @return array|Entity[]
+	 * @return Entity[]
+	 * @psalm-return E[]
+	 * @psalm-template T as self::TYPE_*
+	 * @psalm-template E as (T is self::TYPE_FOLDER ? Folder : (T is self::TYPE_BOOKMARK ? Bookmark : SharedFolder))
 	 */
 	public function findByAncestorFolder(string $type, int $folderId): array {
 		$descendants = [];
@@ -293,7 +306,7 @@ class TreeMapper extends QBMapper {
 
 	/**
 	 * @param int $folderId
-	 * @param string $type
+	 * @param self::TYPE_* $type
 	 * @param int $descendantId
 	 * @return bool
 	 */
@@ -305,7 +318,7 @@ class TreeMapper extends QBMapper {
 			$ancestors = array_flatten(array_map(function (Entity $ancestor) {
 				return $this->findParentsOf(self::TYPE_FOLDER, $ancestor->getId());
 			}, $ancestors));
-			if (0 === count($ancestors)) {
+			if (count($ancestors) === 0) {
 				return false;
 			}
 		}
@@ -315,6 +328,7 @@ class TreeMapper extends QBMapper {
 
 	/**
 	 * @param string $type
+	 * @psalm-param self::TYPE_* $type
 	 * @param int $id
 	 * @param int|null $folderId
 	 * @return void
@@ -322,7 +336,7 @@ class TreeMapper extends QBMapper {
 	 * @throws MultipleObjectsReturnedException
 	 * @throws UnsupportedOperation
 	 */
-	public function deleteEntry(string $type, int $id, int $folderId = null): void {
+	public function deleteEntry(string $type, int $id, ?int $folderId = null): void {
 		$this->eventDispatcher->dispatch(BeforeDeleteEvent::class, new BeforeDeleteEvent($type, $id));
 
 		if ($type === self::TYPE_FOLDER) {
@@ -334,7 +348,6 @@ class TreeMapper extends QBMapper {
 
 			// then get all folders in this sub tree
 			$descendantFolders = $this->findByAncestorFolder(self::TYPE_FOLDER, $id);
-			/** @var Folder $folder */
 			$folder = $this->folderMapper->find($id);
 			$descendantFolders[] = $folder;
 
@@ -386,8 +399,10 @@ class TreeMapper extends QBMapper {
 
 	/**
 	 * @param string $type
+	 * @psalm-param self::TYPE_* $type
 	 * @param int $itemId
 	 * @return void
+	 * @throws Exception
 	 */
 	public function remove(string $type, int $itemId): void {
 		$qb = $this->db->getQueryBuilder();
@@ -402,7 +417,7 @@ class TreeMapper extends QBMapper {
 	 * @param int $shareId
 	 * @throws DoesNotExistException
 	 * @throws MultipleObjectsReturnedException
-	 * @throws UnsupportedOperation
+	 * @throws UnsupportedOperation|Exception
 	 */
 	public function deleteShare(int $shareId): void {
 		$share = $this->shareMapper->find($shareId);
@@ -416,25 +431,45 @@ class TreeMapper extends QBMapper {
 
 	/**
 	 * @param string $type
+	 * @psalm-param self::TYPE_* $type
 	 * @param int $itemId
 	 * @param int $newParentFolderId
 	 * @param int|null $index
+	 * @psalm-param 0|positive-int|null $index
 	 * @throws MultipleObjectsReturnedException
 	 * @throws UnsupportedOperation
 	 */
-	public function move(string $type, int $itemId, int $newParentFolderId, int $index = null): void {
+	public function move(string $type, int $itemId, int $newParentFolderId, ?int $index = null): void {
 		if ($type === self::TYPE_BOOKMARK) {
 			throw new UnsupportedOperation('Cannot move Bookmark');
 		}
 		try {
 			// Try to find current parent
-			/** @var Folder $currentParent */
 			$currentParent = $this->findParentOf($type, $itemId);
+		} catch (DoesNotExistException $e) {
+			$currentParent = null;
+		}
 
-			if ($this->hasDescendant($itemId, self::TYPE_FOLDER, $newParentFolderId)) {
-				throw new UnsupportedOperation('Cannot nest a folder inside one of its descendants');
+		if ($type !== self::TYPE_SHARE) {
+			$folderId = $itemId;
+		} else {
+			$sharedFolder = $this->sharedFolderMapper->find($itemId);
+			$folderId = $sharedFolder->getFolderId();
+			$share = $this->shareMapper->findBySharedFolder($sharedFolder->getId());
+
+			// Make sure that the sharer of this share doesn't have a share of the target folder or one of its parents
+			// would make a share loop very probable, which would be very bad. Breaks the whole app.
+
+			if ($this->isFolderSharedWithUser($newParentFolderId, $share->getOwner())) {
+				throw new UnsupportedOperation('Cannot nest a folder shared from user A inside a folder shared with user A');
 			}
+		}
 
+		if ($this->hasDescendant($folderId, self::TYPE_FOLDER, $newParentFolderId)) {
+			throw new UnsupportedOperation('Cannot nest a folder inside one of its descendants');
+		}
+
+		if ($currentParent !== null) {
 			// Item currently has a parent => move.
 
 			$qb = $this->db->getQueryBuilder();
@@ -445,10 +480,8 @@ class TreeMapper extends QBMapper {
 				->where($qb->expr()->eq('id', $qb->createPositionalParameter($itemId, IQueryBuilder::PARAM_INT)))
 				->andWhere($qb->expr()->eq('type', $qb->createPositionalParameter($type)));
 			$qb->execute();
-		} catch (DoesNotExistException $e) {
+		} else {
 			// Item currently has no parent => insert into tree.
-			$currentParent = null;
-
 			$qb = $this->insertQuery;
 			$qb
 				->setParameters(['id' => $itemId,
@@ -471,17 +504,18 @@ class TreeMapper extends QBMapper {
 	/**
 	 * @brief Add a bookmark to a set of folders
 	 * @param string $type
+	 * @psalm-param self::TYPE_BOOKMARK $type
 	 * @param int $itemId
 	 * @param array $folders Set of folders ids to add the bookmark to
 	 * @throws DoesNotExistException
 	 * @throws MultipleObjectsReturnedException
-	 * @throws UnsupportedOperation
+	 * @throws UnsupportedOperation|Exception
 	 */
 	public function setToFolders(string $type, int $itemId, array $folders): void {
 		if ($type !== self::TYPE_BOOKMARK) {
 			throw new UnsupportedOperation('Only bookmarks can be in multiple folders');
 		}
-		if (0 === count($folders)) {
+		if (count($folders) === 0) {
 			return;
 		}
 
@@ -497,12 +531,13 @@ class TreeMapper extends QBMapper {
 	/**
 	 * @brief Add a bookmark to a set of folders
 	 * @param string $type
+	 * @psalm-param self::TYPE_BOOKMARK $type
 	 * @param int $itemId The bookmark reference
 	 * @param array $folders Set of folders ids to add the bookmark to
 	 * @param int|null $index
-	 * @throws UnsupportedOperation
+	 * @throws UnsupportedOperation|Exception
 	 */
-	public function addToFolders(string $type, int $itemId, array $folders, int $index = null): void {
+	public function addToFolders(string $type, int $itemId, array $folders, ?int $index = null): void {
 		if ($type !== self::TYPE_BOOKMARK) {
 			throw new UnsupportedOperation('Only bookmarks can be in multiple folders');
 		}
@@ -531,11 +566,12 @@ class TreeMapper extends QBMapper {
 	/**
 	 * @brief Remove a bookmark from a set of folders
 	 * @param string $type
+	 * @psalm-param self::TYPE_BOOKMARK $type
 	 * @param int $itemId The bookmark reference
 	 * @param array $folders Set of folders ids to add the bookmark to
 	 * @throws DoesNotExistException
 	 * @throws MultipleObjectsReturnedException
-	 * @throws UnsupportedOperation
+	 * @throws UnsupportedOperation|Exception
 	 */
 	public function removeFromFolders(string $type, int $itemId, array $folders): void {
 		if ($type !== self::TYPE_BOOKMARK) {
@@ -556,7 +592,7 @@ class TreeMapper extends QBMapper {
 
 			$foldersLeft--;
 		}
-		if ($foldersLeft <= 0 && $type === self::TYPE_BOOKMARK) {
+		if ($foldersLeft <= 0) {
 			$bm = $this->bookmarkMapper->find($itemId);
 			$this->bookmarkMapper->delete($bm);
 		}
@@ -627,11 +663,12 @@ class TreeMapper extends QBMapper {
 	 * @param $folderId
 	 * @param int $layers The amount of levels to return
 	 *
-	 * @return (array|int|mixed|string)[][] the children each in the format ["id" => int, "type" => 'bookmark' | 'folder' ]
+	 * @return array the children each in the format ["id" => int, "type" => 'bookmark' | 'folder' ]
 	 *
-	 * @psalm-return array<array-key, array{type: mixed|string, id: int, children?: array}>
+	 * @psalm-return list<array{type: 'bookmark'|'folder', id: int, children?: array}>
+	 * @throws Exception
 	 */
-	public function getChildrenOrder(int $folderId, $layers = 0): array {
+	public function getChildrenOrder(int $folderId, int $layers = 0): array {
 		$children = $this->treeCache->get(TreeCacheManager::CATEGORY_CHILDORDER, TreeMapper::TYPE_FOLDER, $folderId);
 		if ($children !== null) {
 			return $children;
@@ -670,9 +707,9 @@ class TreeMapper extends QBMapper {
 	 * @param int $folderId
 	 * @param int $layers [-1, inf]
 	 *
-	 * @return (int|mixed)[][]
+	 * @return array
 	 *
-	 * @psalm-return array<array-key, array{parent_folder: int}>
+	 * @psalm-return list<array{parent_folder: int, id: int, userId: string, userDisplayName: string, children?: array}>
 	 */
 	public function getSubFolders(int $folderId, $layers = 0): array {
 		$folders = $this->treeCache->get(TreeCacheManager::CATEGORY_SUBFOLDERS, TreeMapper::TYPE_FOLDER, $folderId);
@@ -689,9 +726,6 @@ class TreeMapper extends QBMapper {
 			return $array;
 		}, $this->findChildren(self::TYPE_FOLDER, $folderId));
 		$shares = array_map(function (SharedFolder $sharedFolder) use ($layers, $folderId) {
-			/**
-			 * @var $share Share
-			 */
 			$share = $this->shareMapper->findBySharedFolder($sharedFolder->getId());
 			$array = $sharedFolder->toArray();
 			$array['id'] = $share->getFolderId();
@@ -762,37 +796,42 @@ class TreeMapper extends QBMapper {
 	}
 
 	/**
-	 * @return (int|mixed|string)[][]
+	 * @return array
 	 *
-	 * @psalm-return array<array-key, array<string, int|mixed|string>>
+	 * @psalm-return list<array{type: 'bookmark'|'folder', id: int, children?: array}>
 	 */
 	public function getChildren(int $folderId, int $layers = 0): array {
 		$children = $this->treeCache->get(TreeCacheManager::CATEGORY_CHILDREN, TreeMapper::TYPE_FOLDER, $folderId);
 		if ($children !== null) {
 			return $children;
 		}
-		$qb = $this->getChildrenQuery[self::TYPE_BOOKMARK];
-		$this->selectFromType(self::TYPE_BOOKMARK, ['t.index', 't.type'], $qb);
-		$qb->setParameter('parent_folder', $folderId);
-		$childBookmarks = $qb->execute()->fetchAll();
 
-		$qb = $this->getChildrenQuery[self::TYPE_FOLDER];
-		$this->selectFromType(self::TYPE_FOLDER, ['t.index', 't.type'], $qb);
-		$qb->setParameter('parent_folder', $folderId);
-		$childFolders = $qb->execute()->fetchAll();
+		$children = $this->treeCache->get(TreeCacheManager::CATEGORY_CHILDREN_LAYER, TreeMapper::TYPE_FOLDER, $folderId);
 
-		$qb = $this->getChildrenQuery[self::TYPE_SHARE];
-		$this->selectFromType(self::TYPE_SHARE, ['t.index', 't.type'], $qb);
-		$qb->setParameter('parent_folder', $folderId);
-		$childShares = $qb->execute()->fetchAll();
+		if ($children === null) {
+			$qb = $this->getChildrenQuery[self::TYPE_BOOKMARK];
+			$this->selectFromType(self::TYPE_BOOKMARK, ['t.index', 't.type'], $qb);
+			$qb->setParameter('parent_folder', $folderId);
+			$childBookmarks = $qb->execute()->fetchAll();
 
-		$children = array_merge($childBookmarks, $childFolders, $childShares);
-		$indices = array_column($children, 'index');
-		array_multisort($indices, $children);
+			$qb = $this->getChildrenQuery[self::TYPE_FOLDER];
+			$this->selectFromType(self::TYPE_FOLDER, ['t.index', 't.type'], $qb);
+			$qb->setParameter('parent_folder', $folderId);
+			$childFolders = $qb->execute()->fetchAll();
 
-		$bookmark = new Bookmark();
+			$qb = $this->getChildrenQuery[self::TYPE_SHARE];
+			$this->selectFromType(self::TYPE_SHARE, ['t.index', 't.type'], $qb);
+			$qb->setParameter('parent_folder', $folderId);
+			$childShares = $qb->execute()->fetchAll();
 
-		$children = array_map(function ($child) use ($layers, $bookmark) {
+			$children = array_merge($childBookmarks, $childFolders, $childShares);
+			$indices = array_column($children, 'index');
+			array_multisort($indices, $children);
+
+			$this->treeCache->set(TreeCacheManager::CATEGORY_CHILDREN_LAYER, TreeMapper::TYPE_FOLDER, $folderId, $children);
+		}
+
+		$children = array_map(function ($child) use ($layers) {
 			$item = ['type' => $child['type'], 'id' => (int)$child['id'], 'title' => $child['title'], 'userId' => $child['user_id']];
 
 			if ($item['type'] === self::TYPE_SHARE) {
@@ -801,9 +840,7 @@ class TreeMapper extends QBMapper {
 			}
 
 			if ($item['type'] === self::TYPE_BOOKMARK) {
-				foreach (Bookmark::$columns as $col) {
-					$item[$bookmark->columnToProperty($col)] = $child[$col];
-				}
+				$item = array_merge(Bookmark::fromRow(array_intersect_key($child, array_flip(Bookmark::$columns)))->toArray(), $item);
 			}
 
 			if ($item['type'] === self::TYPE_FOLDER && $layers !== 0) {
@@ -859,15 +896,79 @@ class TreeMapper extends QBMapper {
 		$children = $this->getChildren($folder->getId());
 		foreach ($children as $child) {
 			if ($child['type'] === 'bookmark') {
-				/** @var Bookmark $bookmark */
+
 				$bookmark = $this->bookmarkMapper->find($child['id']);
 				$bookmark->setUserId($userId);
 				$this->bookmarkMapper->update($bookmark);
 			} elseif ($child['type'] === 'folder') {
-				/** @var Folder $folder */
 				$folder = $this->folderMapper->find($child['id']);
 				$this->changeFolderOwner($folder, $userId);
 			}
 		}
 	}
+
+	/**
+	 * @param int $folderId
+	 * @param Share $share
+	 * @return boolean
+	 *@throws MultipleObjectsReturnedException
+	 */
+	public function isFolderSharedWithUser(int $folderId, string $userId): bool {
+		try {
+			$this->sharedFolderMapper->findByFolderAndUser($folderId, $userId);
+			return true;
+		} catch (DoesNotExistException) {
+			// noop
+		}
+
+		$ancestors = $this->findParentsOf(self::TYPE_FOLDER, $folderId);
+		foreach ($ancestors as $ancestorFolder) {
+			try {
+				$this->sharedFolderMapper->findByFolderAndUser($ancestorFolder->getId(), $userId);
+				return true;
+			} catch (DoesNotExistException) {
+				// noop
+			}
+		}
+
+		return false;
+	}
+
+	/**
+	 * @param Folder $folder
+	 * @param string $userId
+	 * @return boolean
+	 */
+	public function containsSharedFolderFromUser(Folder $folder, string $userId): bool {
+		$sharedFolders = $this->sharedFolderMapper->findByOwnerAndUser($userId, $folder->getUserId());
+
+		foreach ($sharedFolders as $sharedFolder) {
+			if ($this->hasDescendant($folder->getId(), self::TYPE_SHARE, $sharedFolder->getId())) {
+				return true;
+			}
+		}
+
+		return false;
+	}
+
+	/**
+	 * @param Folder $folder
+	 * @param string $userId
+	 * @return bool
+	 */
+	public function containsFoldersSharedToUser(Folder $folder, string $userId): bool {
+		$sharedFolders = $this->sharedFolderMapper->findByOwnerAndUser($folder->getUserId(), $userId);
+
+		foreach ($sharedFolders as $sharedFolder) {
+			if ($folder->getId() === $sharedFolder->getFolderId()) {
+				return true;
+			}
+			if ($this->hasDescendant($folder->getId(), self::TYPE_FOLDER, $sharedFolder->getFolderId())) {
+				return true;
+			}
+		}
+
+		return false;
+	}
+
 }
