@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
  * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
@@ -28,6 +28,7 @@ use OCP\BackgroundJob\IJobList;
 use OCP\EventDispatcher\IEventDispatcher;
 
 class BookmarkService {
+	public const PROTOCOLS_REGEX = '/^(https?|s?ftp|file|javascript):/i';
 	/**
 	 * @var BookmarkMapper
 	 */
@@ -130,7 +131,7 @@ class BookmarkService {
 	 * @throws UrlParseError
 	 * @throws UserLimitExceededError
 	 */
-	public function create(string $userId, string $url = '', string $title = null, string $description = null, array $tags = null, $folders = []): Bookmark {
+	public function create(string $userId, string $url = '', ?string $title = null, ?string $description = null, ?array $tags = null, $folders = []): Bookmark {
 		$bookmark = null;
 		$ownFolders = array_filter($folders, function ($folderId) use ($userId) {
 			/**
@@ -173,20 +174,20 @@ class BookmarkService {
 	 * @throws UserLimitExceededError
 	 * @throws UnsupportedOperation
 	 */
-	private function _addBookmark($userId, $url, string $title = null, $description = null, array $tags = null, array $folders = []): Bookmark {
+	private function _addBookmark($userId, $url, ?string $title = null, $description = null, ?array $tags = null, array $folders = []): Bookmark {
 		$bookmark = null;
+
 		try {
 			$bookmark = $this->bookmarkMapper->findByUrl($userId, $url);
 		} catch (DoesNotExistException $e) {
-			$protocols = '/^(https?|s?ftp):\/\//i';
-			if (!preg_match($protocols, $url)) {
+			if (!preg_match(self::PROTOCOLS_REGEX, $url)) {
 				// if no allowed protocol is given, evaluate https and https
 				foreach (['https://', 'http://'] as $protocol) {
-					$testUrl = $this->urlNormalizer->normalize($protocol . $url);
 					try {
+						$testUrl = $this->urlNormalizer->normalize($protocol . $url);
 						$bookmark = $this->bookmarkMapper->findByUrl($userId, $testUrl);
 						break;
-					} catch (DoesNotExistException $e) {
+					} catch (UrlParseError|DoesNotExistException $e) {
 						continue;
 					}
 				}
@@ -199,21 +200,26 @@ class BookmarkService {
 			if (!isset($title, $description)) {
 				// Inspect web page (do some light scraping)
 				// allow only http(s) and (s)ftp
-				$protocols = '/^(https?|s?ftp)\:\/\//i';
-				if (preg_match($protocols, $url)) {
-					$data = $this->linkExplorer->get($url);
+				if (preg_match('/^https?:\/\//i', $url)) {
+					$testUrl = $this->urlNormalizer->normalize($url);
+					$data = $this->linkExplorer->get($testUrl);
 				} else {
 					// if no allowed protocol is given, evaluate https and https
-					foreach (['https://', 'http://'] as $protocol) {
+					foreach (['https://', 'http://', ''] as $protocol) {
 						$testUrl = $protocol . $url;
 						$data = $this->linkExplorer->get($testUrl);
 						if (isset($data['basic']['title'])) {
+							$url = $protocol . $url;
 							break;
 						}
 					}
 				}
 			}
 
+			if (!preg_match(self::PROTOCOLS_REGEX, $url)) {
+				throw new UrlParseError();
+			}
+
 			$url = $data['url'] ?? $url;
 			$title = $title ?? $data['basic']['title'] ?? $url;
 			$title = trim($title);
@@ -262,7 +268,7 @@ class BookmarkService {
 	 * @throws UrlParseError
 	 * @throws UserLimitExceededError
 	 */
-	public function update(string $userId, $id, string $url = null, string $title = null, string $description = null, array $tags = null, array $folders = null): ?Bookmark {
+	public function update(string $userId, $id, ?string $url = null, ?string $title = null, ?string $description = null, ?array $tags = null, ?array $folders = null): ?Bookmark {
 		/**
 		 * @var $bookmark Bookmark
 		 */
@@ -279,6 +285,9 @@ class BookmarkService {
 		}
 
 		if ($url !== null) {
+			if (!preg_match(self::PROTOCOLS_REGEX, $url)) {
+				throw new UrlParseError();
+			}
 			if ($url !== $bookmark->getUrl()) {
 				$bookmark->setAvailable(true);
 			}
@@ -322,6 +331,8 @@ class BookmarkService {
 			 * @var $currentOwnFolders Folder[]
 			 */
 			$currentOwnFolders = $this->treeMapper->findParentsOf(TreeMapper::TYPE_BOOKMARK, $bookmark->getId());
+			// Updating user may not be the owner of the bookmark
+			// We have to keep the bookmark in folders that are inaccessible to the current user
 			if ($bookmark->getUserId() !== $userId) {
 				$currentInaccessibleOwnFolders = array_map(static function ($f) {
 					return $f->getId();
@@ -413,6 +424,18 @@ class BookmarkService {
 		}
 	}
 
+	/**
+	 * @param int $id
+	 * @return Bookmark|null
+	 */
+	public function findById(int $id) : ?Bookmark {
+		try {
+			return $this->bookmarkMapper->find($id);
+		} catch (DoesNotExistException|MultipleObjectsReturnedException $e) {
+			return null;
+		}
+	}
+
 	/**
 	 * @param $userId
 	 * @param string $url
@@ -457,7 +480,7 @@ class BookmarkService {
 		 * @var $bookmark Bookmark
 		 */
 		$bookmark = $this->bookmarkMapper->find($id);
-		return $this->bookmarkPreviewer->getImage($bookmark);
+		return $this->bookmarkPreviewer->getImage($bookmark, true);
 	}
 
 	/**
@@ -471,7 +494,7 @@ class BookmarkService {
 		 * @var $bookmark Bookmark
 		 */
 		$bookmark = $this->bookmarkMapper->find($id);
-		return $this->faviconPreviewer->getImage($bookmark);
+		return $this->faviconPreviewer->getImage($bookmark, true);
 	}
 
 	/**
