@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
  * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
@@ -27,7 +27,10 @@ export default {
 		authToken: null,
 		fetchState: {
 			page: 0,
-			query: {},
+			query: {
+				// Set home filter to avoid trying to load *all* bookmark initially until onRoute is called
+				folder: -1,
+			},
 			reachedEnd: false,
 		},
 		loading: {
@@ -49,6 +52,7 @@ export default {
 			limit: 0,
 			backupPath: '',
 			backupEnabled: '1',
+			hasSeenWhatsnew: '',
 		},
 		bookmarks: [],
 		bookmarksById: {},
