@@ -1,12 +1,12 @@
 /*
- * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
  * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
 
 import Vue from 'vue'
 import axios from '@nextcloud/axios'
-import { findFolder } from './findFolder'
+import { findFolder } from './findFolder.js'
 
 export const mutations = {
 	SET_AUTH_TOKEN: 'SET_AUTH_TOKEN',
